@@ -1,24 +1,33 @@
+# frozen-string-literal: true
+
+Sequel::DataObjects.load_driver 'do_postgres'
 Sequel.require 'adapters/shared/postgres'
 
 module Sequel
   Postgres::CONVERTED_EXCEPTIONS << ::DataObjects::Error
   
   module DataObjects
+    Sequel.synchronize do
+      DATABASE_SETUP[:postgres] = proc do |db|
+        db.extend(Sequel::DataObjects::Postgres::DatabaseMethods)
+        db.extend_datasets Sequel::Postgres::DatasetMethods
+      end
+    end
+
     # Adapter, Database, and Dataset support for accessing a PostgreSQL
     # database via DataObjects.
     module Postgres
       # Methods to add to Database instances that access PostgreSQL via
       # DataObjects.
       module DatabaseMethods
+        extend Sequel::Database::ResetIdentifierMangling
         include Sequel::Postgres::DatabaseMethods
         
         # Add the primary_keys and primary_key_sequences instance variables,
         # so we can get the correct return values for inserted rows.
         def self.extended(db)
-          db.instance_eval do
-            @primary_keys = {}
-            @primary_key_sequences = {}
-          end
+          super
+          db.send(:initialize_postgres_adapter)
         end
         
         private
