@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 Sequel::JDBC.load_driver('Java::cubrid.jdbc.driver.CUBRIDDriver')
 Sequel.require 'adapters/shared/cubrid'
 Sequel.require 'adapters/jdbc/transactions'
@@ -30,7 +32,7 @@ module Sequel
             rs = stmt.getGeneratedKeys
             begin
               if rs.next
-                rs.getInt(1)
+                rs.getLong(1)
               end
             rescue NativeException
               nil
