@@ -1,8 +1,29 @@
+# frozen-string-literal: true
+
+Sequel::JDBC.load_driver('com.ibm.db2.jcc.DB2Driver')
 Sequel.require 'adapters/shared/db2'
 Sequel.require 'adapters/jdbc/transactions'
 
 module Sequel
   module JDBC
+    Sequel.synchronize do
+      DATABASE_SETUP[:db2] = proc do |db|
+        db.extend(Sequel::JDBC::DB2::DatabaseMethods)
+        db.dataset_class = Sequel::JDBC::DB2::Dataset
+        com.ibm.db2.jcc.DB2Driver
+      end
+    end
+
+    class TypeConvertor
+      def DB2Clob(r, i)
+        if v = r.getClob(i)
+          v = v.getSubString(1, v.length)
+          v = Sequel::SQL::Blob.new(v) if ::Sequel::DB2::use_clob_as_blob
+          v
+        end
+      end
+    end
+
     class Database
       # Alias the generic JDBC versions so they can be called directly later
       alias jdbc_schema_parse_table schema_parse_table
@@ -32,7 +53,11 @@ module Sequel
         def set_ps_arg(cps, arg, i)
           case arg
           when Sequel::SQL::Blob
-            cps.setString(i, arg)
+            if ::Sequel::DB2.use_clob_as_blob
+              cps.setString(i, arg)
+            else
+              super
+            end
           else
             super
           end
@@ -43,7 +68,7 @@ module Sequel
             sql = IDENTITY_VAL_LOCAL
             rs = log_yield(sql){stmt.executeQuery(sql)}
             rs.next
-            rs.getInt(1)
+            rs.getLong(1)
           end
         end
         
@@ -51,28 +76,17 @@ module Sequel
         def primary_key_index_re
           PRIMARY_KEY_INDEX_RE
         end
+
+        def setup_type_convertor_map
+          super
+          map = @type_convertor_map
+          types = Java::JavaSQL::Types
+          map[types::NCLOB] = map[types::CLOB] = TypeConvertor::INSTANCE.method(:DB2Clob)
+        end
       end
 
       class Dataset < JDBC::Dataset
         include Sequel::DB2::DatasetMethods
-
-        class ::Sequel::JDBC::Dataset::TYPE_TRANSLATOR
-          def db2_clob(v) Sequel::SQL::Blob.new(v.getSubString(1, v.length)) end
-        end
-
-        DB2_CLOB_METHOD = TYPE_TRANSLATOR_INSTANCE.method(:db2_clob)
-      
-        private
-
-        # Return clob as blob if use_clob_as_blob is true
-        def convert_type_proc(v)
-          case v
-          when JAVA_SQL_CLOB
-            ::Sequel::DB2::use_clob_as_blob ? DB2_CLOB_METHOD : super
-          else
-            super
-          end
-        end
       end
     end
   end
