@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 Sequel::JDBC.load_driver('com.mysql.jdbc.Driver', :MySQL)
 Sequel.require 'adapters/shared/mysql'
 
@@ -46,7 +48,7 @@ module Sequel
             rs = stmt.getGeneratedKeys
             begin
               if rs.next
-                rs.getInt(1)
+                rs.getLong(1)
               else
                 0
               end
@@ -54,10 +56,10 @@ module Sequel
               rs.close
             end
           else
-            statement(conn) do |stmt|
-              rs = stmt.executeQuery(LAST_INSERT_ID)
+            statement(conn) do |st|
+              rs = st.executeQuery(LAST_INSERT_ID)
               rs.next
-              rs.getInt(1)
+              rs.getLong(1)
             end
           end
         end
