@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 Sequel::JDBC.load_driver('Java::oracle.jdbc.driver.OracleDriver')
 Sequel.require 'adapters/shared/oracle'
 Sequel.require 'adapters/jdbc/transactions'
@@ -72,7 +74,7 @@ module Sequel
               begin
                 rs = log_yield(sql){stmt.executeQuery(sql)}
                 rs.next
-                rs.getInt(1)
+                rs.getLong(1)
               rescue java.sql.SQLException
                 nil
               end
