@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 Sequel.require 'adapters/shared/sqlanywhere'
 Sequel.require 'adapters/jdbc/transactions'
 
@@ -51,7 +53,7 @@ module Sequel
             sql = LAST_INSERT_ID
             rs = log_yield(sql){stmt.executeQuery(sql)}
             rs.next
-            rs.getInt(1)
+            rs.getLong(1)
           end
         end
 
