@@ -1,7 +1,19 @@
+# frozen-string-literal: true
+
+Sequel::JDBC.load_driver('com.microsoft.sqlserver.jdbc.SQLServerDriver')
 Sequel.require 'adapters/jdbc/mssql'
 
 module Sequel
   module JDBC
+    Sequel.synchronize do
+      DATABASE_SETUP[:sqlserver] = proc do |db|
+        db.extend(Sequel::JDBC::SQLServer::DatabaseMethods)
+        db.extend_datasets Sequel::MSSQL::DatasetMethods
+        db.send(:set_mssql_unicode_strings)
+        com.microsoft.sqlserver.jdbc.SQLServerDriver
+      end
+    end
+
     # Database and Dataset instance methods for SQLServer specific
     # support via JDBC.
     module SQLServer
@@ -19,39 +31,19 @@ module Sequel
         # than getObject() for this column avoids the problem.
         # Reference: http://social.msdn.microsoft.com/Forums/en/sqldataaccess/thread/20df12f3-d1bf-4526-9daa-239a83a8e435
         module MetadataDatasetMethods
-          def process_result_set_convert(cols, result)
-            while result.next
-              row = {}
-              cols.each do |n, i, p|
-                v = (n == :is_autoincrement ? result.getString(i) : result.getObject(i))
-                row[n] = if v
-                  if p
-                    p.call(v)
-                  elsif p.nil?
-                    cols[i-1][2] = p = convert_type_proc(v)
-                    if p
-                      p.call(v)
-                    else
-                      v
-                    end
-                  else
-                    v
-                  end
-                else
-                  v
-                end
-              end
-              yield row
+          def type_convertor(map, meta, type, i)
+            if output_identifier(meta.getColumnLabel(i)) == :is_autoincrement
+              map[Java::JavaSQL::Types::VARCHAR]
+            else
+              super
             end
           end
 
-          def process_result_set_no_convert(cols, result)
-            while result.next
-              row = {}
-              cols.each do |n, i|
-                row[n] = (n == :is_autoincrement ? result.getString(i) : result.getObject(i))
-              end
-              yield row
+          def basic_type_convertor(map, meta, type, i)
+            if output_identifier(meta.getColumnLabel(i)) == :is_autoincrement
+              map[Java::JavaSQL::Types::VARCHAR]
+            else
+              super
             end
           end
         end
