@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 require 'odbc'
 
 module Sequel
@@ -94,13 +96,13 @@ module Sequel
       def fetch_rows(sql)
         execute(sql) do |s|
           i = -1
-          cols = s.columns(true).map{|c| [output_identifier(c.name), i+=1]}
+          cols = s.columns(true).map{|c| [output_identifier(c.name), c.type, i+=1]}
           columns = cols.map{|c| c.at(0)}
           @columns = columns
           if rows = s.fetch_all
             rows.each do |row|
               hash = {}
-              cols.each{|n,i| hash[n] = convert_odbc_value(row[i])}
+              cols.each{|n,t,j| hash[n] = convert_odbc_value(row[j], t)}
               yield hash
             end
           end
@@ -110,7 +112,7 @@ module Sequel
       
       private
 
-      def convert_odbc_value(v)
+      def convert_odbc_value(v, t)
         # When fetching a result set, the Ruby ODBC driver converts all ODBC 
         # SQL types to an equivalent Ruby type; with the exception of
         # SQL_TYPE_DATE, SQL_TYPE_TIME and SQL_TYPE_TIMESTAMP.
@@ -125,7 +127,11 @@ module Sequel
         when ::ODBC::Date
           Date.new(v.year, v.month, v.day)
         else
-          v
+          if t == ::ODBC::SQL_BIT
+            v == 1
+          else
+            v
+          end
         end
       end
       
