@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 require 'oci8'
 Sequel.require 'adapters/shared/oracle'
 
@@ -15,7 +17,7 @@ module Sequel
       
       ORACLE_TYPES = {
         :blob=>lambda{|b| Sequel::SQL::Blob.new(b.read)},
-        :clob=>lambda{|b| b.read}
+        :clob=>lambda(&:read)
       }
 
       # Hash of conversion procs for this database.
@@ -57,7 +59,7 @@ module Sequel
 
       def disconnect_connection(c)
         c.logoff
-      rescue OCIInvalidHandle
+      rescue OCIException
         nil
       end
 
@@ -111,7 +113,6 @@ module Sequel
         'decimal'.freeze=>Float, 'date'.freeze=>Time, 'datetime'.freeze=>Time,
         'time'.freeze=>Time, 'boolean'.freeze=>String, 'blob'.freeze=>OCI8::BLOB}
       def cursor_bind_params(conn, cursor, args)
-        cursor
         i = 0
         args.map do |arg, type|
           i += 1
@@ -123,7 +124,7 @@ module Sequel
           when BigDecimal
             arg = arg.to_f
           when ::Sequel::SQL::Blob
-            raise Error, "Sequel's oracle adapter does not currently support using a blob in a bound variable"
+            arg = ::OCI8::BLOB.new(conn, arg)
           end
           if t = PS_TYPES[type]
             cursor.bind_param(i, arg, t)
@@ -177,7 +178,7 @@ module Sequel
         args = cursor_bind_params(conn, cursor, opts[:arguments])
         log_sql = "EXECUTE #{name}"
         if ps.log_sql
-          log_sql << " ("
+          log_sql += " ("
           log_sql << sql
           log_sql << ")"
         end
@@ -305,6 +306,7 @@ module Sequel
               :allow_null => column.nullable?
           }
           h[:type] = oracle_column_type(h)
+          h[:auto_increment] = h[:type] == :integer if h[:primary_key]
           h[:max_length] = h[:char_size] if h[:type] == :string
           table_schema << [m.call(column.name), h]
         end
@@ -348,52 +350,9 @@ module Sequel
         end
       end
       
-      # Oracle prepared statement uses a new prepared statement each time
-      # it is called, but it does use the bind arguments.
-      module BindArgumentMethods
-        include ArgumentMapper
+      BindArgumentMethods = prepared_statements_module(:bind, ArgumentMapper)
+      PreparedStatementMethods = prepared_statements_module(:prepare, BindArgumentMethods)
 
-        private
-        
-        # Run execute_select on the database with the given SQL and the stored
-        # bind arguments.
-        def execute(sql, opts=OPTS, &block)
-          super(prepared_sql, {:arguments=>bind_arguments}.merge(opts), &block)
-        end
-        
-        # Same as execute, explicit due to intricacies of alias and super.
-        def execute_dui(sql, opts=OPTS, &block)
-          super(prepared_sql, {:arguments=>bind_arguments}.merge(opts), &block)
-        end
-        
-        # Same as execute, explicit due to intricacies of alias and super.
-        def execute_insert(sql, opts=OPTS, &block)
-          super(prepared_sql, {:arguments=>bind_arguments}.merge(opts), &block)
-        end
-      end
-
-      module PreparedStatementMethods
-        include BindArgumentMethods
-          
-        private
-          
-        # Execute the stored prepared statement name and the stored bind
-        # arguments instead of the SQL given.
-        def execute(sql, opts=OPTS, &block)
-          super(prepared_statement_name, opts, &block)
-        end
-         
-        # Same as execute, explicit due to intricacies of alias and super.
-        def execute_dui(sql, opts=OPTS, &block)
-          super(prepared_statement_name, opts, &block)
-        end
-          
-        # Same as execute, explicit due to intricacies of alias and super.
-        def execute_insert(sql, opts=OPTS, &block)
-          super(prepared_statement_name, opts, &block)
-        end
-      end
-        
       # Execute the given type of statement with the hash of values.
       def call(type, bind_vars={}, *values, &block)
         ps = to_prepared_statement(type, values)
