@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 Sequel.require 'adapters/utils/emulate_offset_with_row_number'
 
 module Sequel
@@ -35,12 +37,18 @@ module Sequel
         im = input_identifier_meth(opts[:dataset])
         metadata_dataset.with_sql("SELECT * FROM SYSIBM.SYSCOLUMNS WHERE TBNAME = #{literal(im.call(table))} ORDER BY COLNO").
           collect do |column| 
-            column[:db_type]     = column.delete(:typename)
-            if column[:db_type]  == "DECIMAL"
+            column[:db_type] = column.delete(:typename)
+            if column[:db_type] =~ /\A(VAR)?CHAR\z/
+              column[:db_type] << "(#{column[:length]})"
+            end
+            if column[:db_type] == "DECIMAL"
               column[:db_type] << "(#{column[:longlength]},#{column[:scale]})"
             end
-            column[:allow_null]  = column.delete(:nulls) == 'Y'
-            column[:primary_key] = column.delete(:identity) == 'Y' || !column[:keyseq].nil?
+            column[:allow_null] = column.delete(:nulls) == 'Y'
+            identity = column.delete(:identity) == 'Y'
+            if column[:primary_key] = identity || !column[:keyseq].nil?
+              column[:auto_increment] = identity
+            end
             column[:type]        = schema_column_type(column[:db_type])
             column[:max_length]  = column[:longlength] if column[:type] == :string
             [ m.call(column.delete(:name)), column]
@@ -80,6 +88,25 @@ module Sequel
         true
       end
 
+      # On DB2, a table might need to be REORGed if you are testing existence
+      # of it.  This REORGs automatically if the database raises a specific
+      # error that indicates it should be REORGed.
+      def table_exists?(name)
+        v ||= false # only retry once
+        sch, table_name = schema_and_table(name)
+        name = SQL::QualifiedIdentifier.new(sch, table_name) if sch
+        from(name).first
+        true
+      rescue DatabaseError => e
+        if e.to_s =~ /Operation not allowed for reason code "7" on table/ && v == false
+          # table probably needs reorg
+          reorg(name)
+          v = true
+          retry 
+        end
+        false
+      end
+
       private
 
       # Handle DB2 specific alter table operations.
@@ -116,6 +143,16 @@ module Sequel
         end
       end
 
+      # REORG the related table whenever it is altered.  This is not always
+      # required, but it is necessary for compatibilty with other Sequel
+      # code in many cases.
+      def apply_alter_table(name, ops)
+        alter_table_sql_list(name, ops).each do |sql|
+          execute_ddl(sql)
+          reorg(name)
+        end
+      end
+
       # DB2 uses an identity column for autoincrement.
       def auto_increment_sql
         AUTOINCREMENT
@@ -187,12 +224,12 @@ module Sequel
       # Run the REORG TABLE command for the table, necessary when
       # the table has been altered.
       def reorg(table)
-        synchronize(opts[:server]){|c| c.execute(reorg_sql(table))}
+        execute_ddl(reorg_sql(table))
       end
 
       # The SQL to use for REORGing a table.
       def reorg_sql(table)
-        "CALL ADMIN_CMD(#{literal("REORG TABLE #{table}")})"
+        "CALL SYSPROC.ADMIN_CMD(#{literal("REORG TABLE #{quote_schema_table(table)}")})"
       end
 
       # Treat clob as blob if use_clob_as_blob is true
@@ -290,6 +327,11 @@ module Sequel
         true
       end
 
+      # DB2 supports GROUPING SETS
+      def supports_grouping_sets?
+        true
+      end
+
       # DB2 does not support IS TRUE.
       def supports_is_true?
         false
