@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 Sequel.require %w'emulate_offset_with_row_number split_alter_table', 'adapters/utils'
 
 module Sequel
@@ -37,7 +39,7 @@ module Sequel
       # Execute the given stored procedure with the given name.
       #
       # Options:
-      # :args :: Arguments to stored procedure.  For named argumetns, this should be a
+      # :args :: Arguments to stored procedure.  For named arguments, this should be a
       #          hash keyed by argument named.  For unnamed arguments, this should be an
       #          array.  Output parameters to the function are specified using :output.
       #          You can also name output parameters and provide a type by using an
@@ -131,10 +133,10 @@ module Sequel
         schema, table = schema_and_table(table)
         current_schema = m.call(get(Sequel.function('schema_name')))
         fk_action_map = FOREIGN_KEY_ACTION_MAP
-        ds = metadata_dataset.from(:sys__foreign_keys___fk).
-          join(:sys__foreign_key_columns___fkc, :constraint_object_id => :object_id).
-          join(:sys__all_columns___pc, :object_id => :fkc__parent_object_id,     :column_id => :fkc__parent_column_id).
-          join(:sys__all_columns___rc, :object_id => :fkc__referenced_object_id, :column_id => :fkc__referenced_column_id).
+        ds = metadata_dataset.from(Sequel.lit('[sys].[foreign_keys]').as(:fk)).
+          join(Sequel.lit('[sys].[foreign_key_columns]').as(:fkc), :constraint_object_id => :object_id).
+          join(Sequel.lit('[sys].[all_columns]').as(:pc), :object_id => :fkc__parent_object_id,     :column_id => :fkc__parent_column_id).
+          join(Sequel.lit('[sys].[all_columns]').as(:rc), :object_id => :fkc__referenced_object_id, :column_id => :fkc__referenced_column_id).
           where{{object_schema_name(:fk__parent_object_id) => im.call(schema || current_schema)}}.
           where{{object_name(:fk__parent_object_id) => im.call(table)}}.
           select{[:fk__name, 
@@ -144,7 +146,7 @@ module Sequel
                   :rc__name___referenced_column, 
                   object_schema_name(:fk__referenced_object_id).as(:schema), 
                   object_name(:fk__referenced_object_id).as(:table)]}.
-          order(:name, :fkc__constraint_column_id)
+          order(:fk__name, :fkc__constraint_column_id)
         h = {}
         ds.each do |row|
           if r = h[row[:name]]
@@ -169,10 +171,10 @@ module Sequel
         m = output_identifier_meth
         im = input_identifier_meth
         indexes = {}
-        ds = metadata_dataset.from(:sys__tables___t).
-         join(:sys__indexes___i, :object_id=>:object_id).
-         join(:sys__index_columns___ic, :object_id=>:object_id, :index_id=>:index_id).
-         join(:sys__columns___c, :object_id=>:object_id, :column_id=>:column_id).
+        ds = metadata_dataset.from(Sequel.lit('[sys].[tables]').as(:t)).
+         join(Sequel.lit('[sys].[indexes]').as(:i), :object_id=>:object_id).
+         join(Sequel.lit('[sys].[index_columns]').as(:ic), :object_id=>:object_id, :index_id=>:index_id).
+         join(Sequel.lit('[sys].[columns]').as(:c), :object_id=>:object_id, :column_id=>:column_id).
          select(:i__name, :i__is_unique, :c__name___column).
          where{{t__name=>im.call(table)}}.
          where(:i__is_primary_key=>0, :i__is_disabled=>0).
@@ -428,28 +430,37 @@ module Sequel
         m = output_identifier_meth(opts[:dataset])
         m2 = input_identifier_meth(opts[:dataset])
         tn = m2.call(table_name.to_s)
-        table_id = get{object_id(tn)}
+        table_id = get(Sequel.function(:object_id, tn))
         info_sch_sch = opts[:information_schema_schema]
         inf_sch_qual = lambda{|s| info_sch_sch ? Sequel.qualify(info_sch_sch, s) : Sequel.expr(s)}
         sys_qual = lambda{|s| info_sch_sch ? Sequel.qualify(info_sch_sch, Sequel.qualify(Sequel.lit(''), s)) : Sequel.expr(s)}
 
-        pk_index_id = metadata_dataset.from(sys_qual.call(:sysindexes)).
+        identity_cols = metadata_dataset.from(Sequel.lit('[sys].[columns]')).
+          where(:object_id=>table_id, :is_identity=>true).
+          select_map(:name)
+
+        pk_index_id = metadata_dataset.from(sys_qual.call(Sequel.lit('sysindexes'))).
           where(:id=>table_id, :indid=>1..254){{(status & 2048)=>2048}}.
           get(:indid)
-        pk_cols = metadata_dataset.from(sys_qual.call(:sysindexkeys).as(:sik)).
-          join(sys_qual.call(:syscolumns).as(:sc), :id=>:id, :colid=>:colid).
+        pk_cols = metadata_dataset.from(sys_qual.call(Sequel.lit('sysindexkeys')).as(:sik)).
+          join(sys_qual.call(Sequel.lit('syscolumns')).as(:sc), :id=>:id, :colid=>:colid).
           where(:sik__id=>table_id, :sik__indid=>pk_index_id).
           select_order_map(:sc__name)
+
         ds = metadata_dataset.from(inf_sch_qual.call(:information_schema__tables).as(:t)).
          join(inf_sch_qual.call(:information_schema__columns).as(:c), :table_catalog=>:table_catalog,
               :table_schema => :table_schema, :table_name => :table_name).
          select(:column_name___column, :data_type___db_type, :character_maximum_length___max_chars, :column_default___default, :is_nullable___allow_null, :numeric_precision___column_size, :numeric_scale___scale).
          filter(:c__table_name=>tn)
+
         if schema = opts[:schema]
           ds.filter!(:c__table_schema=>schema)
         end
+
         ds.map do |row|
-          row[:primary_key] = pk_cols.include?(row[:column])
+          if row[:primary_key] = pk_cols.include?(row[:column])
+            row[:auto_increment] = identity_cols.include?(row[:column])
+          end
           row[:allow_null] = row[:allow_null] == 'YES' ? true : false
           row[:default] = nil if blank_object?(row[:default])
           row[:type] = if row[:db_type] =~ DECIMAL_TYPE_RE && row[:scale] == 0
@@ -457,7 +468,7 @@ module Sequel
           else
             schema_column_type(row[:db_type])
           end
-          row[:max_length] = row[:max_chars] if row[:type] == :string
+          row[:max_length] = row[:max_chars] if row[:type] == :string && row[:max_chars] >= 0
           [m.call(row.delete(:column)), row]
         end
       end
@@ -720,6 +731,11 @@ module Sequel
         is_2005_or_later?
       end
 
+      # MSSQL 2005+ supports GROUPING SETS
+      def supports_grouping_sets?
+        is_2008_or_later?
+      end
+
       # MSSQL supports insert_select via the OUTPUT clause.
       def supports_insert_select?
         supports_output_clause? && !opts[:disable_insert_output]
