@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 Sequel.require 'adapters/utils/pg_types'
 
 module Sequel
@@ -64,7 +66,7 @@ module Sequel
       # :where :: Create a partial exclusion constraint, which only affects
       #           a subset of table rows, value should be a filter expression.
       def exclude(elements, opts=OPTS)
-        constraints << {:type => :exclude, :elements => elements}.merge(opts)
+        constraints << {:type => :exclude, :elements => elements}.merge!(opts)
       end
     end
 
@@ -72,7 +74,7 @@ module Sequel
       # Adds an exclusion constraint to an existing table, see
       # CreateTableGenerator#exclude.
       def add_exclusion_constraint(elements, opts=OPTS)
-        @operations << {:op => :add_constraint, :type => :exclude, :elements => elements}.merge(opts)
+        @operations << {:op => :add_constraint, :type => :exclude, :elements => elements}.merge!(opts)
       end
 
       # Validate the constraint with the given name, which should have
@@ -154,6 +156,15 @@ module Sequel
       # having callable values for the conversion proc for that type.
       attr_reader :conversion_procs
 
+      # Add a conversion proc for a named type.  This should be used 
+      # for types without fixed OIDs, which includes all types that
+      # are not included in a default PostgreSQL installation.  If 
+      # a block is given, it is used as the conversion proc, otherwise
+      # the conversion proc is looked up in the PG_NAMED_TYPES hash.
+      def add_named_conversion_proc(name, &block)
+        add_named_conversion_procs(conversion_procs, name=>(block || PG_NAMED_TYPES[name]))
+      end
+
       # Commit an existing prepared transaction with the given transaction
       # identifier string.
       def commit_prepared_transaction(transaction_id, opts=OPTS)
@@ -299,7 +310,7 @@ module Sequel
         ref_ds = base_ds.
           join(:pg_class___cl2, :oid=>:co__confrelid).
           join(:pg_attribute___att2, :attrelid=>:oid, :attnum=>SQL::Function.new(:ANY, :co__confkey)).
-          order(:co__conname, SQL::CaseExpression.new(range.map{|x| [SQL::Subscript.new(:co__conkey, [x]), x]}, 32, :att2__attnum)).
+          order(:co__conname, SQL::CaseExpression.new(range.map{|x| [SQL::Subscript.new(:co__confkey, [x]), x]}, 32, :att2__attnum)).
           select(:co__conname___name, :cl2__relname___table, :att2__attname___refcolumn)
 
         # If a schema is given, we only search in that schema, and the returned :table
@@ -364,7 +375,8 @@ module Sequel
       # :server :: The server to which to send the NOTIFY statement, if the sharding support
       #            is being used.
       def notify(channel, opts=OPTS)
-        sql = "NOTIFY "
+        sql = String.new
+        sql << "NOTIFY "
         dataset.send(:identifier_append, sql, channel)
         if payload = opts[:payload]
           sql << ", "
@@ -570,22 +582,22 @@ module Sequel
         Postgres::AlterTableGenerator
       end
     
-      # Handle :using option for set_column_type op, and the :validate_constraint op.
-      def alter_table_op_sql(table, op)
-        case op[:op]
-        when :set_column_type
-          s = super
-          if using = op[:using]
-            using = Sequel::LiteralString.new(using) if using.is_a?(String)
-            s << ' USING '
-            s << literal(using)
-          end
-          s
-        when :validate_constraint
-          "VALIDATE CONSTRAINT #{quote_identifier(op[:name])}"
-        else
-          super
+      def alter_table_set_column_type_sql(table, op)
+        s = super
+        if using = op[:using]
+          using = Sequel::LiteralString.new(using) if using.is_a?(String)
+          s += ' USING '
+          s << literal(using)
         end
+        s
+      end
+
+      def alter_table_drop_column_sql(table, op)
+        "DROP COLUMN #{'IF EXISTS ' if op[:if_exists]}#{quote_identifier(op[:name])}#{' CASCADE' if op[:cascade]}"
+      end
+
+      def alter_table_validate_constraint_sql(table, op)
+        "VALIDATE CONSTRAINT #{quote_identifier(op[:name])}"
       end
 
       # If the :synchronous option is given and non-nil, set synchronous_commit
@@ -616,6 +628,15 @@ module Sequel
         end
       end
 
+      # Literalize non-String collate options. This is because unquoted collatations
+      # are folded to lowercase, and PostgreSQL used mixed case or capitalized collations.
+      def column_definition_collate_sql(sql, column)
+        if collate = column[:collate]
+          collate = literal(collate) unless collate.is_a?(String)
+          sql << " COLLATE #{collate}"
+        end
+      end
+
       # Handle PostgreSQL specific default format.
       def column_schema_normalize_default(default, type)
         if m = POSTGRES_DEFAULT_RE.match(default)
@@ -658,7 +679,7 @@ module Sequel
         if search_path = @opts[:search_path]
           case search_path
           when String
-            search_path = search_path.split(",").map{|s| s.strip}
+            search_path = search_path.split(",").map(&:strip)
           when Array
             # nil
           else
@@ -675,7 +696,8 @@ module Sequel
         case constraint[:type]
         when :exclude
           elements = constraint[:elements].map{|c, op| "#{literal(c)} WITH #{op}"}.join(', ')
-          sql = "#{"CONSTRAINT #{quote_identifier(constraint[:name])} " if constraint[:name]}EXCLUDE USING #{constraint[:using]||'gist'} (#{elements})#{" WHERE #{filter_expr(constraint[:where])}" if constraint[:where]}"
+          sql = String.new
+          sql << "#{"CONSTRAINT #{quote_identifier(constraint[:name])} " if constraint[:name]}EXCLUDE USING #{constraint[:using]||'gist'} (#{elements})#{" WHERE #{filter_expr(constraint[:where])}" if constraint[:where]}"
           constraint_deferrable_sql_append(sql, constraint[:deferrable])
           sql
         when :foreign_key, :check
@@ -697,7 +719,7 @@ module Sequel
       # Convert the hash of named conversion procs into a hash a oid conversion procs. 
       def convert_named_procs_to_procs(named_procs)
         h = {}
-        from(:pg_type).where(:typtype=>'b', :typname=>named_procs.keys.map{|t| t.to_s}).select_map([:oid, :typname]).each do |oid, name|
+        from(:pg_type).where(:typtype=>['b', 'e'], :typname=>named_procs.keys.map(&:to_s)).select_map([:oid, :typname]).each do |oid, name|
           h[oid.to_i] = named_procs[name.untaint.to_sym]
         end
         h
@@ -742,7 +764,8 @@ module Sequel
 
       # SQL for doing fast table insert from stdin.
       def copy_into_sql(table, opts)
-        sql = "COPY #{literal(table)}"
+        sql = String.new
+        sql << "COPY #{literal(table)}"
         if cols = opts[:columns]
           sql << literal(Array(cols))
         end
@@ -762,7 +785,8 @@ module Sequel
           table
         else
           if opts[:options] || opts[:format]
-            options = " ("
+            options = String.new
+            options << " ("
             options << "FORMAT #{opts[:format]}" if opts[:format]
             options << "#{', ' if opts[:format]}#{opts[:options]}" if opts[:options]
             options << ')'
@@ -827,17 +851,17 @@ module Sequel
         sql = super
 
         if inherits = options[:inherits]
-          sql << " INHERITS (#{Array(inherits).map{|t| quote_schema_table(t)}.join(', ')})"
+          sql += " INHERITS (#{Array(inherits).map{|t| quote_schema_table(t)}.join(', ')})"
         end
 
         if on_commit = options[:on_commit]
           raise(Error, "can't provide :on_commit without :temp to create_table") unless options[:temp]
           raise(Error, "unsupported on_commit option: #{on_commit.inspect}") unless ON_COMMIT.has_key?(on_commit)
-          sql << " ON COMMIT #{ON_COMMIT[on_commit]}"
+          sql += " ON COMMIT #{ON_COMMIT[on_commit]}"
         end
 
         if server = options[:foreign]
-          sql << " SERVER #{quote_identifier(server)}"
+          sql += " SERVER #{quote_identifier(server)}"
           if foreign_opts = options[:options]
             sql << " OPTIONS (#{foreign_opts.map{|k, v| "#{k} #{literal(v.to_s)}"}.join(', ')})"
           end
@@ -849,9 +873,9 @@ module Sequel
       def create_table_as_sql(name, sql, options)
         result = create_table_prefix_sql name, options
         if on_commit = options[:on_commit]
-          result << " ON COMMIT #{ON_COMMIT[on_commit]}"
+          result += " ON COMMIT #{ON_COMMIT[on_commit]}"
         end
-        result << " AS #{sql}"
+        result += " AS #{sql}"
       end
 
       # Use a PostgreSQL-specific create table generator
@@ -906,6 +930,11 @@ module Sequel
         "DROP TRIGGER#{' IF EXISTS' if opts[:if_exists]} #{name} ON #{quote_schema_table(table)}#{' CASCADE' if opts[:cascade]}"
       end
 
+      # Support :foreign tables
+      def drop_table_sql(name, options)
+        "DROP#{' FOREIGN' if options[:foreign]} TABLE#{' IF EXISTS' if options[:if_exists]} #{quote_schema_table(name)}#{' CASCADE' if options[:cascade]}"
+      end
+
       # SQL for dropping a view from the database.
       def drop_view_sql(name, opts=OPTS)
         "DROP #{'MATERIALIZED ' if opts[:materialized]}VIEW#{' IF EXISTS' if opts[:if_exists]} #{quote_schema_table(name)}#{' CASCADE' if opts[:cascade]}"
@@ -1030,12 +1059,6 @@ module Sequel
         "ALTER TABLE #{quote_schema_table(name)} RENAME TO #{quote_identifier(schema_and_table(new_name).last)}"
       end
 
-      # PostgreSQL's autoincrementing primary keys are of type integer or bigint
-      # using a nextval function call as a default.
-      def schema_autoincrementing_primary_key?(schema)
-        super && schema[:default] =~ /\Anextval/io
-      end
-
       # Recognize PostgreSQL interval type.
       def schema_column_type(db_type)
         case db_type
@@ -1081,6 +1104,9 @@ module Sequel
             row.delete(:db_base_type)
           end
           row[:type] = schema_column_type(row[:db_type])
+          if row[:primary_key]
+            row[:auto_increment] = !!(row[:default] =~ /\Anextval/io)
+          end
           [m.call(row.delete(:name)), row]
         end
       end
@@ -1091,7 +1117,8 @@ module Sequel
         read_only = opts[:read_only]
         deferrable = opts[:deferrable]
         if level || !read_only.nil? || !deferrable.nil?
-          sql = "SET TRANSACTION"
+          sql = String.new
+          sql << "SET TRANSACTION"
           sql << " ISOLATION LEVEL #{Sequel::Database::TRANSACTION_ISOLATION_LEVELS[level]}" if level
           sql << " READ #{read_only ? 'ONLY' : 'WRITE'}" unless read_only.nil?
           sql << " #{'NOT ' unless deferrable}DEFERRABLE" unless deferrable.nil?
@@ -1186,10 +1213,10 @@ module Sequel
       WINDOW = " WINDOW ".freeze
       SELECT_VALUES = "VALUES ".freeze
       EMPTY_STRING = ''.freeze
-      LOCK_MODES = ['ACCESS SHARE', 'ROW SHARE', 'ROW EXCLUSIVE', 'SHARE UPDATE EXCLUSIVE', 'SHARE', 'SHARE ROW EXCLUSIVE', 'EXCLUSIVE', 'ACCESS EXCLUSIVE'].each{|s| s.freeze}
+      LOCK_MODES = ['ACCESS SHARE', 'ROW SHARE', 'ROW EXCLUSIVE', 'SHARE UPDATE EXCLUSIVE', 'SHARE', 'SHARE ROW EXCLUSIVE', 'EXCLUSIVE', 'ACCESS EXCLUSIVE'].each(&:freeze)
 
       Dataset.def_sql_method(self, :delete, [['if server_version >= 90100', %w'with delete from using where returning'], ['else', %w'delete from using where returning']])
-      Dataset.def_sql_method(self, :insert, [['if server_version >= 90100', %w'with insert into columns values returning'], ['else', %w'insert into columns values returning']])
+      Dataset.def_sql_method(self, :insert, [['if server_version >= 90500', %w'with insert into columns values conflict returning'], ['elsif server_version >= 90100', %w'with insert into columns values returning'], ['else', %w'insert into columns values returning']])
       Dataset.def_sql_method(self, :select, [['if opts[:values]', %w'values order limit'], ['elsif server_version >= 80400', %w'with select distinct columns from join where group having window compounds order limit lock'], ['else', %w'select distinct columns from join where group having compounds order limit lock']])
       Dataset.def_sql_method(self, :update, [['if server_version >= 90100', %w'with update table set from where returning'], ['else', %w'update table set from where returning']])
 
@@ -1197,7 +1224,7 @@ module Sequel
       module PreparedStatementMethods
         # Override insert action to use RETURNING if the server supports it.
         def run
-          if @prepared_type == :insert
+          if @prepared_type == :insert && (opts[:returning_pk] || !opts[:returning])
             fetch_rows(prepared_sql){|r| return r.values.first}
           else
             super
@@ -1206,7 +1233,10 @@ module Sequel
 
         def prepared_sql
           return @prepared_sql if @prepared_sql
-          @opts[:returning] = insert_pk if @prepared_type == :insert
+          if @prepared_type == :insert && !opts[:returning]
+            @opts[:returning] = insert_pk
+            @opts[:returning_pk] = true
+          end
           super
           @prepared_sql
         end
@@ -1282,22 +1312,33 @@ module Sequel
       # :phrase :: Similar to :plain, but also adding an ILIKE filter to ensure that
       #            returned rows also include the exact phrase used.
       # :rank :: Set to true to order by the rank, so that closer matches are returned first.
+      # :tsquery :: Specifies the terms argument is already a valid SQL expression returning a
+      #             tsquery, and can be used directly in the query.
+      # :tsvector :: Specifies the cols argument is already a valid SQL expression returning a
+      #              tsvector, and can be used directly in the query.
       def full_text_search(cols, terms, opts = OPTS)
         lang = Sequel.cast(opts[:language] || 'simple', :regconfig)
-        terms = terms.join(' | ') if terms.is_a?(Array)
-        columns = full_text_string_join(cols)
-        query_func = (opts[:phrase] || opts[:plain]) ? :plainto_tsquery : :to_tsquery
-        vector = Sequel.function(:to_tsvector, lang, columns)
-        query = Sequel.function(query_func, lang, terms)
 
-        ds = where(Sequel.lit(["(", " @@ ", ")"], vector, query))
+        unless opts[:tsvector]
+          phrase_cols = full_text_string_join(cols)
+          cols = Sequel.function(:to_tsvector, lang, phrase_cols)
+        end
+
+        unless opts[:tsquery]
+          phrase_terms = terms.is_a?(Array) ? terms.join(' | ') : terms
+          query_func = (opts[:phrase] || opts[:plain]) ? :plainto_tsquery : :to_tsquery
+          terms = Sequel.function(query_func, lang, phrase_terms)
+        end
+
+        ds = where(Sequel.lit(["(", " @@ ", ")"], cols, terms))
 
         if opts[:phrase]
-          ds = ds.grep(cols, "%#{escape_like(terms)}%", :case_insensitive=>true)
+          raise Error, "can't use :phrase with either :tsvector or :tsquery arguments to full_text_search together" if opts[:tsvector] || opts[:tsquery]
+          ds = ds.grep(phrase_cols, "%#{escape_like(phrase_terms)}%", :case_insensitive=>true)
         end
 
         if opts[:rank]
-          ds = ds.order{ts_rank_cd(vector, query)}
+          ds = ds.reverse{ts_rank_cd(cols, terms)}
         end
 
         ds
@@ -1320,11 +1361,55 @@ module Sequel
         end
       end
 
+      # Handle uniqueness violations when inserting, by updating the conflicting row, using
+      # ON CONFLICT. With no options, uses ON CONFLICT DO NOTHING.  Options:
+      # :constraint :: An explicit constraint name, has precendence over :target.
+      # :target :: The column name or expression to handle uniqueness violations on.
+      # :update :: A hash of columns and values to set.  Uses ON CONFLICT DO UPDATE.
+      # :update_where :: A WHERE condition to use for the update.
+      #
+      # Examples:
+      #
+      #   DB[:table].insert_conflict.insert(:a=>1, :b=>2)
+      #   # INSERT INTO TABLE (a, b) VALUES (1, 2)
+      #   # ON CONFLICT DO NOTHING
+      #   
+      #   DB[:table].insert_conflict(:constraint=>:table_a_uidx).insert(:a=>1, :b=>2)
+      #   # INSERT INTO TABLE (a, b) VALUES (1, 2)
+      #   # ON CONFLICT ON CONSTRAINT table_a_uidx DO NOTHING
+      #   
+      #   DB[:table].insert_conflict(:target=>:a).insert(:a=>1, :b=>2)
+      #   # INSERT INTO TABLE (a, b) VALUES (1, 2)
+      #   # ON CONFLICT (a) DO NOTHING
+      #   
+      #   DB[:table].insert_conflict(:target=>:a, :update=>{:b=>:excluded__b}).insert(:a=>1, :b=>2)
+      #   # INSERT INTO TABLE (a, b) VALUES (1, 2)
+      #   # ON CONFLICT (a) DO UPDATE SET b = excluded.b
+      #   
+      #   DB[:table].insert_conflict(:constraint=>:table_a_uidx,
+      #     :update=>{:b=>:excluded__b}, :update_where=>{:table__status_id=>1}).insert(:a=>1, :b=>2)
+      #   # INSERT INTO TABLE (a, b) VALUES (1, 2)
+      #   # ON CONFLICT ON CONSTRAINT table_a_uidx
+      #   # DO UPDATE SET b = excluded.b WHERE (table.status_id = 1)
+      def insert_conflict(opts=OPTS)
+        clone(:insert_conflict => opts)
+      end
+
+      # Ignore uniqueness/exclusion violations when inserting, using ON CONFLICT DO NOTHING.
+      # Exists mostly for compatibility to MySQL's insert_ignore. Example:
+      #
+      #   DB[:table].insert_ignore.insert(:a=>1, :b=>2)
+      #   # INSERT INTO TABLE (a, b) VALUES (1, 2)
+      #   # ON CONFLICT DO NOTHING
+      def insert_ignore
+        insert_conflict
+      end
+
       # Insert a record returning the record inserted.  Always returns nil without
       # inserting a query if disable_insert_returning is used.
       def insert_select(*values)
         return unless supports_insert_select?
-        with_sql_first(insert_select_sql(*values))
+        server?(:default).with_sql_first(insert_select_sql(*values))
       end
 
       # The SQL to use for an insert_select, adds a RETURNING clause to the insert
@@ -1343,7 +1428,7 @@ module Sequel
         if block_given? # perform locking inside a transaction and yield to block
           @db.transaction(opts){lock(mode, opts); yield}
         else
-          sql = 'LOCK TABLE '
+          sql = 'LOCK TABLE '.dup
           source_list_append(sql, @opts[:from])
           mode = mode.to_s.upcase.strip
           unless LOCK_MODES.include?(mode)
@@ -1374,11 +1459,31 @@ module Sequel
         true
       end
 
+      # PostgreSQL 9.5+ supports GROUP CUBE
+      def supports_group_cube?
+        server_version >= 90500
+      end
+
+      # PostgreSQL 9.5+ supports GROUP ROLLUP
+      def supports_group_rollup?
+        server_version >= 90500
+      end
+
+      # PostgreSQL 9.5+ supports GROUPING SETS
+      def supports_grouping_sets?
+        server_version >= 90500
+      end
+
       # True unless insert returning has been disabled for this dataset.
       def supports_insert_select?
         !@opts[:disable_insert_returning]
       end
 
+      # PostgreSQL 9.5+ supports the ON CONFLICT clause to INSERT.
+      def supports_insert_conflict?
+        server_version >= 90500
+      end
+
       # PostgreSQL 9.3rc1+ supports lateral subqueries
       def supports_lateral_subqueries?
         server_version >= 90300
@@ -1446,7 +1551,7 @@ module Sequel
       def _import(columns, values, opts=OPTS)
         if @opts[:returning]
           statements = multi_insert_sql(columns, values)
-          @db.transaction(opts.merge(:server=>@opts[:server])) do
+          @db.transaction(Hash[opts].merge!(:server=>@opts[:server])) do
             statements.map{|st| returning_fetch_rows(st)}
           end.first.map{|v| v.length == 1 ? v.values.first : v}
         elsif opts[:return] == :primary_key
@@ -1481,6 +1586,34 @@ module Sequel
         join_from_sql(:USING, sql)
       end
 
+      # Add ON CONFLICT clause if it should be used
+      def insert_conflict_sql(sql)
+        if opts = @opts[:insert_conflict]
+          sql << " ON CONFLICT"
+
+          if target = opts[:constraint] 
+            sql << " ON CONSTRAINT "
+            identifier_append(sql, target)
+          elsif target = opts[:target]
+            sql << ' ('
+            identifier_append(sql, target)
+            sql << ')'
+          end
+
+          if values = opts[:update]
+            sql << " DO UPDATE SET "
+            update_sql_values_hash(sql, values)
+            if where = opts[:update_where]
+              sql << " WHERE "
+              literal_append(sql, where)
+            end
+          else
+            sql << " DO NOTHING"
+          end
+
+        end
+      end
+
       # Return the primary key to use for RETURNING in an INSERT statement
       def insert_pk
         if (f = opts[:from]) && !f.empty?
