@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   module SqlAnywhere
 
@@ -56,8 +58,9 @@ module Sequel
          from{sa_describe_query("select * from #{im.call(table)}").as(:a)}.
          join(:syscolumn___b, :table_id=>:base_table_id, :column_id=>:base_column_id).
          order(:a__column_number).
-          map do |row|
-          row[:auto_increment] = row.delete(:is_autoincrement) == 1
+         map do |row|
+          auto_increment = row.delete(:is_autoincrement)
+          row[:auto_increment] = auto_increment == 1 || auto_increment == true
           row[:primary_key] = row.delete(:pkey) == 'Y'
           row[:allow_null] = row[:nulls_allowed].is_a?(Fixnum) ? row.delete(:nulls_allowed) == 1 : row.delete(:nulls_allowed)
           row[:db_type] = row.delete(:domain_name)
@@ -282,6 +285,11 @@ module Sequel
         type == :select || type == :insert
       end
 
+      # SQLAnywhere supports GROUPING SETS
+      def supports_grouping_sets?
+        true
+      end
+
       def supports_multiple_column_in?
         false
       end
@@ -323,7 +331,7 @@ module Sequel
           sql << Sequel::Dataset::PAREN_OPEN
           literal_append(sql, args.at(0))
           sql << Sequel::Dataset::SPACE << (op == :LIKE ? REGEXP : NOT_REGEXP) << Sequel::Dataset::SPACE
-          pattern = ''
+          pattern = String.new
           last_c = ''
           args.at(1).each_char do |c|
             if  c == '_' and not pattern.end_with?('\\') and last_c != '\\'
