@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   # The +ASTTransformer+ class is designed to handle the abstract syntax trees
   # that Sequel uses internally and produce modified copies of them.  By itself
@@ -69,7 +71,7 @@ module Sequel
       when SQL::JoinClause
         SQL::JoinClause.new(o.join_type, v(o.table_expr))
       when SQL::DelayedEvaluation
-        SQL::DelayedEvaluation.new(lambda{v(o.callable.call)})
+        SQL::DelayedEvaluation.new(lambda{|ds| v(o.call(ds))})
       when SQL::Wrapper
         SQL::Wrapper.new(v(o.value))
       else
