@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 # A ShardedSingleConnectionPool is a single threaded connection pool that
 # works with multiple shards/servers.
 class Sequel::ShardedSingleConnectionPool < Sequel::ConnectionPool
@@ -54,6 +56,11 @@ class Sequel::ShardedSingleConnectionPool < Sequel::ConnectionPool
     end
   end
   
+  # The ShardedSingleConnectionPool always has a maximum size of 1.
+  def max_size
+    1
+  end
+  
   # Remove servers from the connection pool. Primarily used in conjunction with master/slave
   # or shard configurations.  Similar to disconnecting from all given servers,
   # except that after it is used, future requests for the server will use the
@@ -94,5 +101,10 @@ class Sequel::ShardedSingleConnectionPool < Sequel::ConnectionPool
     @servers[server]
   end
   
+  # Make sure there is a valid connection for each server.
+  def preconnect
+    servers.each{|s| hold(s){}}
+  end
+  
   CONNECTION_POOL_MAP[[true, true]] = self
 end
