@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   class Database
     # ---------------------
@@ -119,7 +121,7 @@ module Sequel
     # :no_index :: Set to true not to create the second index.
     # :no_primary_key :: Set to true to not create the primary key.
     def create_join_table(hash, options=OPTS)
-      keys = hash.keys.sort_by{|k| k.to_s}
+      keys = hash.keys.sort_by(&:to_s)
       create_table(join_table_name(hash, options), options) do
         keys.each do |key|
           v = hash[key]
@@ -142,7 +144,7 @@ module Sequel
     
     # Creates the join table unless it already exists.
     def create_join_table?(hash, options=OPTS)
-      if supports_create_table_if_not_exists?
+      if supports_create_table_if_not_exists? && options[:no_index]
         create_join_table(hash, options.merge(:if_not_exists=>true))
       elsif !table_exists?(join_table_name(hash, options))
         create_join_table(hash, options)
@@ -215,10 +217,12 @@ module Sequel
     #   # SELECT NULL FROM a LIMIT 1 -- check existence
     #   # CREATE TABLE a (a integer) -- if it doesn't already exist
     def create_table?(name, options=OPTS, &block)
-      if supports_create_table_if_not_exists?
-        create_table(name, options.merge(:if_not_exists=>true), &block)
+      options = options.dup
+      generator = options[:generator] ||= create_table_generator(&block)
+      if generator.indexes.empty? && supports_create_table_if_not_exists?
+        create_table(name, options.merge!(:if_not_exists=>true))
       elsif !table_exists?(name)
-        create_table(name, options, &block)
+        create_table(name, options)
       end
     end
 
@@ -428,32 +432,50 @@ module Sequel
     
     # SQL fragment for given alter table operation.
     def alter_table_op_sql(table, op)
-      quoted_name = quote_identifier(op[:name]) if op[:name]
-      case op[:op]
-      when :add_column
-        "ADD COLUMN #{column_definition_sql(op)}"
-      when :drop_column
-        "DROP COLUMN #{quoted_name}#{' CASCADE' if op[:cascade]}"
-      when :rename_column
-        "RENAME COLUMN #{quoted_name} TO #{quote_identifier(op[:new_name])}"
-      when :set_column_type
-        "ALTER COLUMN #{quoted_name} TYPE #{type_literal(op)}"
-      when :set_column_default
-        "ALTER COLUMN #{quoted_name} SET DEFAULT #{literal(op[:default])}"
-      when :set_column_null
-        "ALTER COLUMN #{quoted_name} #{op[:null] ? 'DROP' : 'SET'} NOT NULL"
-      when :add_constraint
-        "ADD #{constraint_definition_sql(op)}"
-      when :drop_constraint
-        if op[:type] == :foreign_key
-          quoted_name ||= quote_identifier(foreign_key_name(table, op[:columns]))
-        end
-        "DROP CONSTRAINT #{quoted_name}#{' CASCADE' if op[:cascade]}"
+      meth = "alter_table_#{op[:op]}_sql"
+      if respond_to?(meth, true)
+        send(meth, table, op)
       else
         raise Error, "Unsupported ALTER TABLE operation: #{op[:op]}"
       end
     end
 
+    def alter_table_add_column_sql(table, op)
+      "ADD COLUMN #{column_definition_sql(op)}"
+    end
+
+    def alter_table_drop_column_sql(table, op)
+      "DROP COLUMN #{quote_identifier(op[:name])}#{' CASCADE' if op[:cascade]}"
+    end
+
+    def alter_table_rename_column_sql(table, op)
+      "RENAME COLUMN #{quote_identifier(op[:name])} TO #{quote_identifier(op[:new_name])}"
+    end
+
+    def alter_table_set_column_type_sql(table, op)
+      "ALTER COLUMN #{quote_identifier(op[:name])} TYPE #{type_literal(op)}"
+    end
+
+    def alter_table_set_column_default_sql(table, op)
+      "ALTER COLUMN #{quote_identifier(op[:name])} SET DEFAULT #{literal(op[:default])}"
+    end
+
+    def alter_table_set_column_null_sql(table, op)
+      "ALTER COLUMN #{quote_identifier(op[:name])} #{op[:null] ? 'DROP' : 'SET'} NOT NULL"
+    end
+
+    def alter_table_add_constraint_sql(table, op)
+      "ADD #{constraint_definition_sql(op)}"
+    end
+
+    def alter_table_drop_constraint_sql(table, op)
+      quoted_name = quote_identifier(op[:name]) if op[:name]
+      if op[:type] == :foreign_key
+        quoted_name ||= quote_identifier(foreign_key_name(table, op[:columns]))
+      end
+      "DROP CONSTRAINT #{quoted_name}#{' CASCADE' if op[:cascade]}"
+    end
+
     # The SQL to execute to modify the DDL for the given table name.  op
     # should be one of the operations returned by the AlterTableGenerator.
     def alter_table_sql(table, op)
@@ -510,7 +532,8 @@ module Sequel
 
     # SQL DDL fragment containing the column creation SQL for the given column.
     def column_definition_sql(column)
-      sql = "#{quote_identifier(column[:name])} #{type_literal(column)}"
+      sql = String.new
+      sql << "#{quote_identifier(column[:name])} #{type_literal(column)}"
       column_definition_order.each{|m| send(:"column_definition_#{m}_sql", sql, column)}
       sql
     end
@@ -522,7 +545,9 @@ module Sequel
 
     # Add collate SQL fragment to column creation SQL.
     def column_definition_collate_sql(sql, column)
-      sql << " COLLATE #{column[:collate]}" if column[:collate]
+      if collate = column[:collate]
+        sql << " COLLATE #{collate}"
+      end
     end
 
     # Add default SQL fragment to column creation SQL.
@@ -579,7 +604,8 @@ module Sequel
 
     # SQL DDL fragment for column foreign key references
     def column_references_sql(column)
-      sql = " REFERENCES #{quote_schema_table(column[:table])}"
+      sql = String.new
+      sql << " REFERENCES #{quote_schema_table(column[:table])}"
       sql << "(#{Array(column[:key]).map{|x| quote_identifier(x)}.join(COMMA_SEPARATOR)})" if column[:key]
       sql << " ON DELETE #{on_delete_clause(column[:on_delete])}" if column[:on_delete]
       sql << " ON UPDATE #{on_update_clause(column[:on_update])}" if column[:on_update]
@@ -600,7 +626,8 @@ module Sequel
 
     # SQL DDL fragment specifying a constraint on a table.
     def constraint_definition_sql(constraint)
-      sql = constraint[:name] ? "CONSTRAINT #{quote_identifier(constraint[:name])} " : ""
+      sql = String.new
+      sql << "CONSTRAINT #{quote_identifier(constraint[:name])} " if constraint[:name] 
       case constraint[:type]
       when :check
         check = constraint[:check]
@@ -704,7 +731,8 @@ module Sequel
     # DDL statement for creating a view.
     def create_view_sql(name, source, options)
       source = source.sql if source.is_a?(Dataset)
-      sql = "#{create_view_prefix_sql(name, options)} AS #{source}"
+      sql = String.new
+      sql << "#{create_view_prefix_sql(name, options)} AS #{source}"
       if check = options[:check]
         sql << " WITH#{' LOCAL' if check == :local} CHECK OPTION"
       end
@@ -713,6 +741,7 @@ module Sequel
 
     # Append the column list to the SQL, if a column list is given.
     def create_view_sql_append_columns(sql, columns)
+      sql = sql.dup
       if columns
         sql << ' ('
         schema_utility_dataset.send(:identifier_list_append, sql, columns)
@@ -779,7 +808,7 @@ module Sequel
         options[:name]
       else
         table_names = entries.map{|e| join_table_name_extract(e)}
-        table_names.map{|t| t.to_s}.sort.join('_')
+        table_names.map(&:to_s).sort.join('_')
       end
     end
 
@@ -835,7 +864,7 @@ module Sequel
 
     # Return true if the given column schema represents an autoincrementing primary key.
     def schema_autoincrementing_primary_key?(schema)
-      !!(schema[:primary_key] && schema[:db_type] =~ /int/io)
+      !!(schema[:primary_key] && schema[:auto_increment])
     end
 
     # The dataset to use for proxying certain schema methods.
