@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   class Database
     # ---------------------
@@ -45,6 +47,9 @@ module Sequel
     # :num_retries :: The number of times to retry if the :retry_on option is used.
     #                 The default is 5 times.  Can be set to nil to retry indefinitely,
     #                 but that is not recommended.
+    # :before_retry :: Proc to execute before rertrying if the :retry_on option is used.
+    #                  Called with two arguments: the number of retry attempts (counting
+    #                  the current one) and the error the last attempt failed with.
     # :prepare :: A string to use as the transaction identifier for a
     #             prepared transaction (two-phase commit), if the database/adapter
     #             supports prepared transactions.
@@ -57,7 +62,8 @@ module Sequel
     # :rollback :: Can the set to :reraise to reraise any Sequel::Rollback exceptions
     #              raised, or :always to always rollback even if no exceptions occur
     #              (useful for testing).
-    # :server :: The server to use for the transaction.
+    # :server :: The server to use for the transaction. Set to :default, :read_only, or
+    #            whatever symbol you used in the connect string when naming your servers.
     # :savepoint :: Whether to create a new savepoint for this transaction,
     #               only respected if the database/adapter supports savepoints.  By
     #               default Sequel will reuse an existing transaction, so if you want to
@@ -73,13 +79,17 @@ module Sequel
     #                 and :remote_write (9.2+).
     def transaction(opts=OPTS, &block)
       if retry_on = opts[:retry_on]
-        num_retries = opts.fetch(:num_retries, 5)
+        tot_retries = opts.fetch(:num_retries, 5)
+        num_retries = 0 unless tot_retries.nil?
         begin
-          transaction(opts.merge(:retry_on=>nil, :retrying=>true), &block)
-        rescue *retry_on
+          transaction(Hash[opts].merge!(:retry_on=>nil, :retrying=>true), &block)
+        rescue *retry_on => e
           if num_retries
-            num_retries -= 1
-            retry if num_retries >= 0
+            num_retries += 1
+            if num_retries <= tot_retries
+              opts[:before_retry].call(num_retries, e) if opts[:before_retry]
+              retry
+            end
           else
             retry
           end
@@ -88,12 +98,12 @@ module Sequel
       else
         synchronize(opts[:server]) do |conn|
           if already_in_transaction?(conn, opts)
-            if opts[:retrying]
-              raise Sequel::Error, "cannot set :retry_on options if you are already inside a transaction"
-            end
             if opts[:savepoint] != false && (stack = _trans(conn)[:savepoints]) && stack.last
-              _transaction(conn, opts.merge(:savepoint=>true), &block)
+              _transaction(conn, Hash[opts].merge!(:savepoint=>true), &block)
             else
+              if opts[:retrying]
+                raise Sequel::Error, "cannot set :retry_on options if you are already inside a transaction"
+              end
               return yield(conn)
             end
           else
@@ -116,7 +126,7 @@ module Sequel
         begin_transaction(conn, opts)
         if rollback == :always
           begin
-            yield(conn)
+            ret = yield(conn)
           rescue Exception => e1
             raise e1
           ensure
@@ -131,6 +141,7 @@ module Sequel
         rescue Exception
         end
         transaction_error(e, :conn=>conn, :rollback=>rollback)
+        ret
       ensure
         begin
           committed = commit_or_rollback_transaction(e, conn, opts)
@@ -179,20 +190,6 @@ module Sequel
       end
     end    
 
-    # Call all stored after_commit blocks for the given transaction
-    def after_transaction_commit(conn)
-      if ary = _trans(conn)[:after_commit]
-        ary.each{|b| b.call}
-      end
-    end
-
-    # Call all stored after_rollback blocks for the given transaction
-    def after_transaction_rollback(conn)
-      if ary = _trans(conn)[:after_rollback]
-        ary.each{|b| b.call}
-      end
-    end
-
     # Whether the current thread/connection is already inside a transaction
     def already_in_transaction?(conn, opts)
       _trans(conn) && (!supports_savepoints? || !opts[:savepoint])
@@ -280,14 +277,10 @@ module Sequel
     # Remove the current thread from the list of active transactions
     def remove_transaction(conn, committed)
       if transaction_finished?(conn)
-        begin
-          if committed
-            after_transaction_commit(conn)
-          else
-            after_transaction_rollback(conn)
-          end
-        ensure
-          Sequel.synchronize{@transactions.delete(conn)}
+        callbacks = _trans(conn)[committed ? :after_commit : :after_rollback]
+        Sequel.synchronize{@transactions.delete(conn)}
+        if callbacks
+          callbacks.each(&:call)
         end
       end
     end
