@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   class Dataset
     # ---------------------
@@ -8,11 +10,11 @@ module Sequel
     # ---------------------
     
     # Action methods defined by Sequel that execute code on the database.
-    ACTION_METHODS = (<<-METHS).split.map{|x| x.to_sym}
+    ACTION_METHODS = (<<-METHS).split.map(&:to_sym)
       << [] all avg count columns columns! delete each
       empty? fetch_rows first first! get import insert interval last
       map max min multi_insert paged_each range select_hash select_hash_groups select_map select_order_map
-      single_record single_value sum to_hash to_hash_groups truncate update
+      single_record single_record! single_value single_value! sum to_hash to_hash_groups truncate update
     METHS
 
     # Inserts the given argument into the database.  Returns self so it
@@ -146,7 +148,8 @@ module Sequel
     #   DB[:table].empty? # SELECT 1 AS one FROM table LIMIT 1
     #   # => false
     def empty?
-      get(Sequel::SQL::AliasedExpression.new(1, :one)).nil?
+      ds = @opts[:order] ? unordered : self
+      ds.get(Sequel::SQL::AliasedExpression.new(1, :one)).nil?
     end
 
     # If a integer argument is given, it is interpreted as a limit, and then returns all 
@@ -202,7 +205,7 @@ module Sequel
     # Calls first.  If first returns nil (signaling that no
     # row matches), raise a Sequel::NoMatchingRow exception.
     def first!(*args, &block)
-      first(*args, &block) || raise(Sequel::NoMatchingRow)
+      first(*args, &block) || raise(Sequel::NoMatchingRow.new(self))
     end
 
     # Return the column value for the first matching record in the dataset.
@@ -267,7 +270,7 @@ module Sequel
     # :commit_every :: Open a new transaction for every given number of records.
     #                  For example, if you provide a value of 50, will commit
     #                  after every 50 records.
-    # :return :: When the :value is :primary_key, returns an array of
+    # :return :: When this is set to :primary_key, returns an array of
     #            autoincremented primary key values for the rows inserted.
     # :server :: Set the server/shard to use for the transaction and insert
     #            queries.
@@ -297,7 +300,7 @@ module Sequel
     #
     # +insert+ handles a number of different argument formats:
     # no arguments or single empty hash :: Uses DEFAULT VALUES
-    # single hash :: Most common format, treats keys as columns an values as values
+    # single hash :: Most common format, treats keys as columns and values as values
     # single array :: Treats entries as values, with no columns
     # two arrays :: Treats first array as columns, second array as values
     # single Dataset :: Treats as an insert based on a selection from the dataset given,
@@ -448,7 +451,7 @@ module Sequel
     #              for using an approach with a limit and offset for every page.  This can
     #              be set to :filter, which uses a limit and a filter that excludes
     #              rows from previous pages.  In order for this strategy to work, you must be
-    #              selecting the columns you are ordering by, and non of the columns can contain
+    #              selecting the columns you are ordering by, and none of the columns can contain
     #              NULLs.  Note that some Sequel adapters have optimized implementations that will
     #              use cursors or streaming regardless of the :strategy option used.
     # :filter_values :: If the :strategy=>:filter option is used, this option should be a proc
@@ -485,11 +488,15 @@ module Sequel
       unless @opts[:order]
         raise Sequel::Error, "Dataset#paged_each requires the dataset be ordered"
       end
+      unless block_given?
+        return enum_for(:paged_each, opts)
+      end
 
       total_limit = @opts[:limit]
       offset = @opts[:offset]
       if server = @opts[:server]
-        opts = opts.merge(:server=>server)
+        opts = Hash[opts]
+        opts[:server] = server
       end
 
       rows_per_fetch = opts[:rows_per_fetch] || 1000
@@ -632,22 +639,51 @@ module Sequel
       _select_map(column, true, &block)
     end
 
-    # Returns the first record in the dataset, or nil if the dataset
-    # has no records. Users should probably use +first+ instead of
-    # this method.
+    # Limits the dataset to one record, and returns the first record in the dataset,
+    # or nil if the dataset has no records. Users should probably use +first+ instead of
+    # this method. Example:
+    #
+    #   DB[:test].single_record # SELECT * FROM test LIMIT 1
+    #   # => {:column_name=>'value'}
     def single_record
-      clone(:limit=>1).each{|r| return r}
-      nil
+      clone(:limit=>1).single_record!
+    end
+
+    # Returns the first record in dataset, without limiting the dataset. Returns nil if
+    # the dataset has no records. Users should probably use +first+ instead of this method.
+    # This should only be used if you know the dataset is already limited to a single record.
+    # This method may be desirable to use for performance reasons, as it does not clone the
+    # receiver. Example:
+    #
+    #   DB[:test].single_record! # SELECT * FROM test
+    #   # => {:column_name=>'value'}
+    def single_record!
+      with_sql_first(select_sql)
     end
 
     # Returns the first value of the first record in the dataset.
     # Returns nil if dataset is empty.  Users should generally use
-    # +get+ instead of this method.
+    # +get+ instead of this method. Example:
+    #
+    #   DB[:test].single_value # SELECT * FROM test LIMIT 1
+    #   # => 'value'
     def single_value
       if r = ungraphed.naked.single_record
-        r.values.first
+        r.each{|_, v| return v}
       end
     end
+
+    # Returns the first value of the first record in the dataset, without limiting the dataset.
+    # Returns nil if the dataset is empty. Users should generally use +get+ instead of this
+    # method.  Should not be used on graphed datasets or datasets that have row_procs that
+    # don't return hashes.  This method may be desirable to use for performance reasons, as
+    # it does not clone the receiver.
+    #
+    #   DB[:test].single_value! # SELECT * FROM test
+    #   # => 'value'
+    def single_value!
+      with_sql_single_value(select_sql)
+    end
     
     # Returns the sum for the given column/expression.
     # Uses a virtual row block if no column is given.
@@ -697,7 +733,7 @@ module Sequel
           end
         end
       elsif key_column.is_a?(Array)
-        each{|r| h[r.values_at(*key_column)] = r}
+        each{|r| h[key_column.map{|k| r[k]}] = r}
       else
         each{|r| h[r[key_column]] = r}
       end
@@ -740,7 +776,7 @@ module Sequel
           end
         end
       elsif key_column.is_a?(Array)
-        each{|r| (h[r.values_at(*key_column)] ||= []) << r}
+        each{|r| (h[key_column.map{|k| r[k]}] ||= []) << r}
       else
         each{|r| (h[r[key_column]] ||= []) << r}
       end
@@ -763,7 +799,7 @@ module Sequel
     #   DB[:table].update(:x=>nil) # UPDATE table SET x = NULL
     #   # => 10
     #
-    #   DB[:table].update(:x=>:x+1, :y=>0) # UPDATE table SET x = (x + 1), y = 0
+    #   DB[:table].update(:x=>Sequel.expr(:x)+1, :y=>0) # UPDATE table SET x = (x + 1), y = 0
     #   # => 10
     def update(values=OPTS, &block)
       sql = update_sql(values)
@@ -813,7 +849,7 @@ module Sequel
     # only a single value.  See with_sql_each.
     def with_sql_single_value(sql)
       if r = with_sql_first(sql)
-        r.values.first
+        r.each{|_, v| return v}
       end
     end
 
@@ -829,7 +865,7 @@ module Sequel
     # separate insert commands for each row.  Otherwise, call #multi_insert_sql
     # and execute each statement it gives separately.
     def _import(columns, values, opts)
-      trans_opts = opts.merge(:server=>@opts[:server])
+      trans_opts = Hash[opts].merge!(:server=>@opts[:server])
       if opts[:return] == :primary_key
         @db.transaction(trans_opts){values.map{|v| insert(columns, v)}}
       else
@@ -897,13 +933,23 @@ module Sequel
 
     # Set the server to use to :default unless it is already set in the passed opts
     def default_server_opts(opts)
-      {:server=>@opts[:server] || :default}.merge(opts)
+      if @db.sharded?
+        opts = Hash[opts]
+        opts[:server] = @opts[:server] || :default
+      end
+      opts
     end
 
     # Execute the given select SQL on the database using execute. Use the
     # :read_only server unless a specific server is set.
     def execute(sql, opts=OPTS, &block)
-      @db.execute(sql, {:server=>@opts[:server] || :read_only}.merge(opts), &block)
+      db = @db
+      if db.sharded?
+        opts = Hash[opts]
+        opts[:server] = @opts[:server] || (@opts[:lock] ? :default : :read_only)
+        opts
+      end
+      db.execute(sql, opts, &block)
     end
     
     # Execute the given SQL on the database using execute_ddl.
@@ -977,7 +1023,7 @@ module Sequel
         [v, descending]
       end
 
-      row_values = yield(row, order_exprs.map{|e| e.first})
+      row_values = yield(row, order_exprs.map(&:first))
 
       last_expr = []
       cond = order_exprs.zip(row_values).map do |(v, descending), value|
