@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   class Dataset
     # ---------------------
@@ -76,6 +78,11 @@ module Sequel
       false
     end
 
+    # Whether the dataset supports GROUPING SETS with GROUP BY.
+    def supports_grouping_sets?
+      false
+    end
+
     # Whether this dataset supports the +insert_select+ method for returning all columns values
     # directly from an insert query.
     def supports_insert_select?
