@@ -1,10 +1,12 @@
+# frozen-string-literal: true
+
 module Sequel
   class Dataset
     # ---------------------
     # :section: 5 - Methods related to dataset graphing
-    # Dataset graphing changes the dataset to yield hashes where keys are table
-    # name symbols and values are hashes representing the columns related to
-    # that table.  All of these methods return modified copies of the receiver.
+    # Dataset graphing automatically creates unique aliases columns in join
+    # tables that overlap with already selected column aliases. 
+    # All of these methods return modified copies of the receiver.
     # ---------------------
     
     # Adds the given graph aliases to the list of graph aliases to use,
@@ -13,46 +15,20 @@ module Sequel
     #
     #   DB[:table].add_graph_aliases(:some_alias=>[:table, :column])
     #   # SELECT ..., table.column AS some_alias
-    #   # => {:table=>{:column=>some_alias_value, ...}, ...}
     def add_graph_aliases(graph_aliases)
+      unless (ga = opts[:graph_aliases]) || (opts[:graph] && (ga = opts[:graph][:column_aliases]))
+        raise Error, "cannot call add_graph_aliases on a dataset that has not been called with graph or set_graph_aliases"
+      end
       columns, graph_aliases = graph_alias_columns(graph_aliases)
-      ds = select_more(*columns)
-      ds.opts[:graph_aliases] = (ds.opts[:graph_aliases] || (ds.opts[:graph][:column_aliases] rescue {}) || {}).merge(graph_aliases)
-      ds
+      select_more(*columns).clone(:graph_aliases => Hash[ga].merge!(graph_aliases))
     end
 
-    # Allows you to join multiple datasets/tables and have the result set
-    # split into component tables.
-    #
-    # This differs from the usual usage of join, which returns the result set
-    # as a single hash.  For example:
-    #
-    #   # CREATE TABLE artists (id INTEGER, name TEXT);
-    #   # CREATE TABLE albums (id INTEGER, name TEXT, artist_id INTEGER);
-    #
-    #   DB[:artists].left_outer_join(:albums, :artist_id=>:id).first
-    #   #=> {:id=>albums.id, :name=>albums.name, :artist_id=>albums.artist_id}
-    #
-    #   DB[:artists].graph(:albums, :artist_id=>:id).first
-    #   #=> {:artists=>{:id=>artists.id, :name=>artists.name}, :albums=>{:id=>albums.id, :name=>albums.name, :artist_id=>albums.artist_id}}
-    #
-    # Using a join such as left_outer_join, the attribute names that are shared between
-    # the tables are combined in the single return hash.  You can get around that by
-    # using +select+ with correct aliases for all of the columns, but it is simpler to
-    # use +graph+ and have the result set split for you.  In addition, +graph+ respects
-    # any +row_proc+ of the current dataset and the datasets you use with +graph+.
-    #
-    # If you are graphing a table and all columns for that table are nil, this
-    # indicates that no matching rows existed in the table, so graph will return nil
-    # instead of a hash with all nil values:
-    #
-    #   # If the artist doesn't have any albums
-    #   DB[:artists].graph(:albums, :artist_id=>:id).first
-    #   => {:artists=>{:id=>artists.id, :name=>artists.name}, :albums=>nil}
+    # Similar to Dataset#join_table, but uses unambiguous aliases for selected
+    # columns and keeps metadata about the aliases for use in other methods.
     #
     # Arguments:
     # dataset :: Can be a symbol (specifying a table), another dataset,
-    #            or an object that responds to +dataset+ and returns a symbol or a dataset
+    #            or an SQL::Identifier, SQL::QualifiedIdentifier, or SQL::AliasedExpression.
     # join_conditions :: Any condition(s) allowed by +join_table+.
     # block :: A block that is passed to +join_table+.
     #
@@ -62,6 +38,7 @@ module Sequel
     #                     the receiver is wrapped in a from_self before graphing, and this option
     #                     determines the alias to use.
     # :implicit_qualifier :: The qualifier of implicit conditions, see #join_table.
+    # :join_only :: Only join the tables, do not change the selected columns.
     # :join_type :: The type of join to use (passed to +join_table+).  Defaults to :left_outer.
     # :qualify:: The type of qualification to do, see #join_table.
     # :select :: An array of columns to select.  When not used, selects
@@ -70,28 +47,41 @@ module Sequel
     #            some metadata about the join that makes it important to use +graph+ instead
     #            of +join_table+.
     # :table_alias :: The alias to use for the table.  If not specified, doesn't
-    #                 alias the table.  You will get an error if the the alias (or table) name is
+    #                 alias the table.  You will get an error if the alias (or table) name is
     #                 used more than once.
-    def graph(dataset, join_conditions = nil, options = {}, &block)
-      # Allow the use of a model, dataset, or symbol as the first argument
+    def graph(dataset, join_conditions = nil, options = OPTS, &block)
+      # Allow the use of a dataset or symbol as the first argument
       # Find the table name/dataset based on the argument
-      dataset = dataset.dataset if dataset.respond_to?(:dataset)
       table_alias = options[:table_alias]
+      table = dataset
+      create_dataset = true
+
       case dataset
       when Symbol
-        table = dataset
-        dataset = @db[dataset]
-        table_alias ||= table
-      when ::Sequel::Dataset
+        # let alias be the same as the table name (sans any optional schema)
+        # unless alias explicitly given in the symbol using ___ notation
+        table_alias ||= split_symbol(table).compact.last
+      when Dataset
         if dataset.simple_select_all?
           table = dataset.opts[:from].first
           table_alias ||= table
         else
-          table = dataset
           table_alias ||= dataset_alias((@opts[:num_dataset_sources] || 0)+1)
         end
+        create_dataset = false
+      when SQL::Identifier
+        table_alias ||= table.value
+      when SQL::QualifiedIdentifier
+        table_alias ||= split_qualifiers(table).last
+      when SQL::AliasedExpression
+        return graph(table.expression, join_conditions, {:table_alias=>table.alias}.merge!(options), &block)
       else
-        raise Error, "The dataset argument should be a symbol, dataset, or model"
+        raise Error, "The dataset argument should be a symbol or dataset"
+      end
+      table_alias = table_alias.to_sym
+
+      if create_dataset
+        dataset = db.from(table)
       end
 
       # Raise Sequel::Error with explanation that the table alias has been used
@@ -103,11 +93,22 @@ module Sequel
       # Only allow table aliases that haven't been used
       raise_alias_error.call if @opts[:graph] && @opts[:graph][:table_aliases] && @opts[:graph][:table_aliases].include?(table_alias)
       
-      # Use a from_self if this is already a joined table
-      ds = (!@opts[:graph] && (@opts[:from].length > 1 || @opts[:join])) ? from_self(:alias=>options[:from_self_alias] || first_source) : self
+      table_alias_qualifier = qualifier_from_alias_symbol(table_alias, table)
+      implicit_qualifier = options[:implicit_qualifier]
+      ds = self
+
+      # Use a from_self if this is already a joined table (or from_self specifically disabled for graphs)
+      if (@opts[:graph_from_self] != false && !@opts[:graph] && joined_dataset?)
+        from_selfed = true
+        implicit_qualifier = options[:from_self_alias] || first_source
+        ds = ds.from_self(:alias=>implicit_qualifier)
+      end
       
       # Join the table early in order to avoid cloning the dataset twice
-      ds = ds.join_table(options[:join_type] || :left_outer, table, join_conditions, :table_alias=>table_alias, :implicit_qualifier=>options[:implicit_qualifier], :qualify=>options[:qualify], &block)
+      ds = ds.join_table(options[:join_type] || :left_outer, table, join_conditions, :table_alias=>table_alias_qualifier, :implicit_qualifier=>implicit_qualifier, :qualify=>options[:qualify], &block)
+
+      return ds if options[:join_only]
+
       opts = ds.opts
 
       # Whether to include the table in the result set
@@ -115,52 +116,50 @@ module Sequel
       # Whether to add the columns to the list of column aliases
       add_columns = !ds.opts.include?(:graph_aliases)
 
-      # Setup the initial graph data structure if it doesn't exist
       if graph = opts[:graph]
         opts[:graph] = graph = graph.dup
         select = opts[:select].dup
         [:column_aliases, :table_aliases, :column_alias_num].each{|k| graph[k] = graph[k].dup}
       else
-        master = alias_symbol(ds.first_source_alias)
+        # Setup the initial graph data structure if it doesn't exist
+        qualifier = ds.first_source_alias
+        master = alias_symbol(qualifier)
         raise_alias_error.call if master == table_alias
+
         # Master hash storing all .graph related information
         graph = opts[:graph] = {}
+
         # Associates column aliases back to tables and columns
         column_aliases = graph[:column_aliases] = {}
+
         # Associates table alias (the master is never aliased)
         table_aliases = graph[:table_aliases] = {master=>self}
+
         # Keep track of the alias numbers used
         ca_num = graph[:column_alias_num] = Hash.new(0)
+
         # All columns in the master table are never
         # aliased, but are not included if set_graph_aliases
         # has been used.
         if add_columns
           if (select = @opts[:select]) && !select.empty? && !(select.length == 1 && (select.first.is_a?(SQL::ColumnAll)))
-            select = select.each do |sel|
-              column = case sel
-              when Symbol
-                _, c, a = split_symbol(sel)
-                (a || c).to_sym
-              when SQL::Identifier
-                sel.value.to_sym
-              when SQL::QualifiedIdentifier
-                column = sel.column
-                column = column.value if column.is_a?(SQL::Identifier)
-                column.to_sym
-              when SQL::AliasedExpression
-                column = sel.aliaz
-                column = column.value if column.is_a?(SQL::Identifier)
-                column.to_sym
-              else
-                raise Error, "can't figure out alias to use for graphing for #{sel.inspect}"
-              end
+            select = select.map do |sel|
+              raise Error, "can't figure out alias to use for graphing for #{sel.inspect}" unless column = _hash_key_symbol(sel)
               column_aliases[column] = [master, column]
+              if from_selfed
+                # Initial dataset was wrapped in subselect, selected all
+                # columns in the subselect, qualified by the subselect alias.
+                Sequel.qualify(qualifier, Sequel.identifier(column))
+              else
+                # Initial dataset not wrapped in subslect, just make
+                # sure columns are qualified in some way.
+                qualified_expression(sel, qualifier)
+              end
             end
-            select = qualified_expression(select, master)
           else
             select = columns.map do |column|
               column_aliases[column] = [master, column]
-              SQL::QualifiedIdentifier.new(master, column)
+              SQL::QualifiedIdentifier.new(qualifier, column)
             end
           end
         end
@@ -192,9 +191,9 @@ module Sequel
               column_alias = :"#{column_alias}_#{column_alias_num}" 
               ca_num[column_alias] += 1
             end
-            [column_alias, SQL::AliasedExpression.new(SQL::QualifiedIdentifier.new(table_alias, column), column_alias)]
+            [column_alias, SQL::AliasedExpression.new(SQL::QualifiedIdentifier.new(table_alias_qualifier, column), column_alias)]
           else
-            ident = SQL::QualifiedIdentifier.new(table_alias, column)
+            ident = SQL::QualifiedIdentifier.new(table_alias_qualifier, column)
             [column, ident]
           end
           column_aliases[col_alias] = [table_alias, column]
@@ -227,7 +226,6 @@ module Sequel
     #                       :album_name=>[:albums, :name],
     #                       :forty_two=>[:albums, :fourtwo, 42]).first
     #   # SELECT artists.name, albums.name AS album_name, 42 AS forty_two ...
-    #   # => {:artists=>{:name=>artists.name}, :albums=>{:name=>albums.name, :fourtwo=>42}}
     def set_graph_aliases(graph_aliases)
       columns, graph_aliases = graph_alias_columns(graph_aliases)
       ds = select(*columns)
@@ -243,6 +241,20 @@ module Sequel
 
     private
 
+    # Wrap the alias symbol in an SQL::Identifier if the identifier on which is based
+    # is an SQL::Identifier.  This works around cases where the alias symbol contains
+    # double embedded underscores which would be considered an implicit qualified identifier
+    # if not wrapped in an SQL::Identifier.
+    def qualifier_from_alias_symbol(aliaz, identifier)
+      identifier = identifier.column if identifier.is_a?(SQL::QualifiedIdentifier)
+      case identifier
+      when SQL::Identifier
+        Sequel.identifier(aliaz)
+      else
+        aliaz
+      end
+    end
+
     # Transform the hash of graph aliases and return a two element array
     # where the first element is an array of identifiers suitable to pass to
     # a select method, and the second is a new hash of preprocessed graph aliases.
@@ -258,46 +270,5 @@ module Sequel
       end
       [identifiers, gas]
     end
-
-    # Fetch the rows, split them into component table parts,
-    # tranform and run the row_proc on each part (if applicable),
-    # and yield a hash of the parts.
-    def graph_each
-      # Reject tables with nil datasets, as they are excluded from
-      # the result set
-      datasets = @opts[:graph][:table_aliases].to_a.reject{|ta,ds| ds.nil?}
-      # Get just the list of table aliases into a local variable, for speed
-      table_aliases = datasets.collect{|ta,ds| ta}
-      # Get an array of arrays, one for each dataset, with
-      # the necessary information about each dataset, for speed
-      datasets = datasets.collect{|ta, ds| [ta, ds, ds.row_proc]}
-      # Use the manually set graph aliases, if any, otherwise
-      # use the ones automatically created by .graph
-      column_aliases = @opts[:graph_aliases] || @opts[:graph][:column_aliases]
-      fetch_rows(select_sql) do |r|
-        graph = {}
-        # Create the sub hashes, one per table
-        table_aliases.each{|ta| graph[ta]={}}
-        # Split the result set based on the column aliases
-        # If there are columns in the result set that are
-        # not in column_aliases, they are ignored
-        column_aliases.each do |col_alias, tc|
-          ta, column = tc
-          graph[ta][column] = r[col_alias]
-        end
-        # For each dataset run the row_proc if applicable
-        datasets.each do |ta,ds,rp|
-          g = graph[ta]
-          graph[ta] = if g.values.any?{|x| !x.nil?}
-            rp ? rp.call(g) : g
-          else
-            nil
-          end
-        end
-
-        yield graph
-      end
-      self
-    end
   end
 end
