@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   class Dataset
     # ---------------------
@@ -16,7 +18,7 @@ module Sequel
 
     # Which options don't affect the SQL generation.  Used by simple_select_all?
     # to determine if this is a simple SELECT * FROM table.
-    NON_SQL_OPTIONS = [:server, :defaults, :overrides, :graph, :eager_graph, :graph_aliases]
+    NON_SQL_OPTIONS = [:server, :defaults, :overrides, :graph, :eager, :eager_graph, :graph_aliases]
     
     # These symbols have _join methods created (e.g. inner_join) that
     # call join_table with the symbol, passing along the arguments and
@@ -32,9 +34,9 @@ module Sequel
     JOIN_METHODS = (CONDITIONED_JOIN_TYPES + UNCONDITIONED_JOIN_TYPES).map{|x| "#{x}_join".to_sym} + [:join, :join_table]
     
     # Methods that return modified datasets
-    QUERY_METHODS = (<<-METHS).split.map{|x| x.to_sym} + JOIN_METHODS
+    QUERY_METHODS = (<<-METHS).split.map(&:to_sym) + JOIN_METHODS
       add_graph_aliases and distinct except exclude exclude_having exclude_where
-      filter for_update from from_self graph grep group group_and_count group_by having intersect invert
+      filter for_update from from_self graph grep group group_and_count group_append group_by having intersect invert
       limit lock_style naked offset or order order_append order_by order_more order_prepend qualify
       reverse reverse_order select select_all select_append select_group select_more server
       set_graph_aliases unfiltered ungraphed ungrouped union
@@ -74,24 +76,26 @@ module Sequel
     def clone(opts = nil)
       c = super()
       if opts
-        c.instance_variable_set(:@opts, @opts.merge(opts))
+        c.instance_variable_set(:@opts, Hash[@opts].merge!(opts))
         c.instance_variable_set(:@columns, nil) if @columns && !opts.each_key{|o| break if COLUMN_CHANGE_OPTS.include?(o)}
       else
-        c.instance_variable_set(:@opts, @opts.dup)
+        c.instance_variable_set(:@opts, Hash[@opts])
       end
       c
     end
 
-    # Returns a copy of the dataset with the SQL DISTINCT clause.
-    # The DISTINCT clause is used to remove duplicate rows from the
-    # output.  If arguments are provided, uses a DISTINCT ON clause,
-    # in which case it will only be distinct on those columns, instead
-    # of all returned columns.  Raises an error if arguments
-    # are given and DISTINCT ON is not supported.
+    # Returns a copy of the dataset with the SQL DISTINCT clause. The DISTINCT
+    # clause is used to remove duplicate rows from the output.  If arguments
+    # are provided, uses a DISTINCT ON clause, in which case it will only be
+    # distinct on those columns, instead of all returned columns. If a block
+    # is given, it is treated as a virtual row block, similar to +where+.
+    # Raises an error if arguments are given and DISTINCT ON is not supported.
     #
     #  DB[:items].distinct # SQL: SELECT DISTINCT * FROM items
     #  DB[:items].order(:id).distinct(:id) # SQL: SELECT DISTINCT ON (id) * FROM items ORDER BY id
-    def distinct(*args)
+    #  DB[:items].order(:id).distinct{func(:id)} # SQL: SELECT DISTINCT ON (func(id)) * FROM items ORDER BY id
+    def distinct(*args, &block)
+      virtual_row_columns(args, block)
       raise(InvalidOperation, "DISTINCT ON not supported") if !args.empty? && !supports_distinct_on?
       clone(:distinct => args)
     end
@@ -312,6 +316,17 @@ module Sequel
       select_group(*columns, &block).select_more(COUNT_OF_ALL_AS_COUNT)
     end
 
+    # Returns a copy of the dataset with the given columns added to the list of
+    # existing columns to group on. If no existing columns are present this
+    # method simply sets the columns as the initial ones to group on.
+    #
+    #   DB[:items].group_append(:b) # SELECT * FROM items GROUP BY b
+    #   DB[:items].group(:a).group_append(:b) # SELECT * FROM items GROUP BY a, b
+    def group_append(*columns, &block)
+      columns = @opts[:group] + columns if @opts[:group]
+      group(*columns, &block)
+    end
+
     # Adds the appropriate CUBE syntax to GROUP BY.
     def group_cube
       raise Error, "GROUP BY CUBE not supported on #{db.database_type}" unless supports_group_cube?
@@ -324,6 +339,12 @@ module Sequel
       clone(:group_options=>:rollup)
     end
 
+    # Adds the appropriate GROUPING SETS syntax to GROUP BY.
+    def grouping_sets
+      raise Error, "GROUP BY GROUPING SETS not supported on #{db.database_type}" unless supports_grouping_sets?
+      clone(:group_options=>:"grouping sets")
+    end
+
     # Returns a copy of the dataset with the HAVING conditions changed. See #where for argument types.
     #
     #   DB[:items].group(:sum).having(:sum=>10)
@@ -574,7 +595,10 @@ module Sequel
     # A symbol may be used for database independent locking behavior, but
     # all supported symbols have separate methods (e.g. for_update).
     #
-    #   DB[:items].lock_style('FOR SHARE NOWAIT') # SELECT * FROM items FOR SHARE NOWAIT
+    #   DB[:items].lock_style('FOR SHARE NOWAIT')
+    #   # SELECT * FROM items FOR SHARE NOWAIT
+    #   DB[:items].lock_style('FOR UPDATE OF table1 SKIP LOCKED')
+    #   # SELECT * FROM items FOR UPDATE OF table1 SKIP LOCKED
     def lock_style(style)
       clone(:lock => style)
     end
@@ -582,7 +606,7 @@ module Sequel
     # Returns a cloned dataset without a row_proc.
     #
     #   ds = DB[:items]
-    #   ds.row_proc = proc{|r| r.invert}
+    #   ds.row_proc = proc(&:invert)
     #   ds.all # => [{2=>:id}]
     #   ds.naked.all # => [{:id=>2}]
     def naked
@@ -792,6 +816,17 @@ module Sequel
       clone(:server=>servr)
     end
 
+    # If the database uses sharding and the current dataset has not had a
+    # server set, return a cloned dataset that uses the given server.
+    # Otherwise, return the receiver directly instead of returning a clone.
+    def server?(server)
+      if db.sharded? && !opts[:server]
+        server(server)
+      else
+        self
+      end
+    end
+
     # Unbind bound variables from this dataset's filter and return an array of two
     # objects.  The first object is a modified dataset where the filter has been
     # replaced with one that uses bound variable placeholders.  The second object
@@ -926,7 +961,7 @@ module Sequel
         s, ds = hoist_cte(dataset)
         s.with(name, ds, opts)
       else
-        clone(:with=>(@opts[:with]||[]) + [opts.merge(:name=>name, :dataset=>dataset)])
+        clone(:with=>(@opts[:with]||[]) + [Hash[opts].merge!(:name=>name, :dataset=>dataset)])
       end
     end
 
@@ -955,7 +990,7 @@ module Sequel
         s, ds = hoist_cte(recursive)
         s.with_recursive(name, nonrecursive, ds, opts)
       else
-        clone(:with=>(@opts[:with]||[]) + [opts.merge(:recursive=>true, :name=>name, :dataset=>nonrecursive.union(recursive, {:all=>opts[:union_all] != false, :from_self=>false}))])
+        clone(:with=>(@opts[:with]||[]) + [Hash[opts].merge!(:recursive=>true, :name=>name, :dataset=>nonrecursive.union(recursive, {:all=>opts[:union_all] != false, :from_self=>false}))])
       end
     end
     
@@ -988,7 +1023,7 @@ module Sequel
         s, ds = hoist_cte(dataset)
         return s.compound_clone(type, ds, opts)
       end
-      ds = compound_from_self.clone(:compounds=>Array(@opts[:compounds]).map{|x| x.dup} + [[type, dataset.compound_from_self, opts[:all]]])
+      ds = compound_from_self.clone(:compounds=>Array(@opts[:compounds]).map(&:dup) + [[type, dataset.compound_from_self, opts[:all]]])
       opts[:from_self] == false ? ds : ds.from_self(opts)
     end
 
@@ -1117,7 +1152,7 @@ module Sequel
     # Return self if the dataset already has a server, or a cloned dataset with the
     # default server otherwise.
     def default_server
-      @opts[:server] ? self : clone(:server=>:default)
+      server?(:default)
     end
 
     # Treat the +block+ as a virtual_row block if not +nil+ and
