@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   class Model
     extend Enumerable
@@ -468,7 +470,7 @@ module Sequel
       # An alias for calling first! on the model's dataset, but with
       # optimized handling of the single argument case.
       def first!(*args, &block)
-        first(*args, &block) || raise(Sequel::NoMatchingRow)
+        first(*args, &block) || raise(Sequel::NoMatchingRow.new(dataset))
       end
 
       # Clear the setter_methods cache when a module is included, as it
@@ -489,7 +491,7 @@ module Sequel
       #   end
       def inherited(subclass)
         super
-        ivs = subclass.instance_variables.collect{|x| x.to_s}
+        ivs = subclass.instance_variables.collect(&:to_s)
         inherited_instance_variables.each do |iv, dup|
           next if ivs.include?(iv.to_s)
           if (sup_class_value = instance_variable_get(iv)) && dup
@@ -508,15 +510,13 @@ module Sequel
           end
           subclass.instance_variable_set(iv, sup_class_value)
         end
+
         unless ivs.include?("@dataset")
-          if self == Model || !@dataset
-            n = subclass.name
-            unless n.nil? || n.empty?
-              db
-              subclass.set_dataset(subclass.implicit_table_name) rescue nil
-            end
-          elsif @dataset
+          if @dataset && self != Model
             subclass.set_dataset(@dataset.clone, :inherited=>true) rescue nil
+          elsif (n = subclass.name) && !n.to_s.empty?
+            db
+            subclass.set_dataset(subclass.implicit_table_name) rescue nil
           end
         end
       end
@@ -580,14 +580,15 @@ module Sequel
       #   Artist.primary_key_hash(1) # => {:id=>1}
       #   Artist.primary_key_hash([1, 2]) # => {:id1=>1, :id2=>2}
       def primary_key_hash(value)
-        raise(Error, "#{self} does not have a primary key") unless key = @primary_key
-        case key
+        case key = @primary_key
+        when Symbol
+          {key => value}
         when Array
           hash = {}
-          key.each_with_index{|k,i| hash[k] = value[i]}
+          key.zip(Array(value)){|k,v| hash[k] = v}
           hash
         else
-          {key => value}
+          raise(Error, "#{self} does not have a primary key")
         end
       end
 
@@ -599,9 +600,16 @@ module Sequel
       #   Artist.filter(Artist.qualified_primary_key_hash(1))
       #   # SELECT * FROM artists WHERE (artists.id = 1)
       def qualified_primary_key_hash(value, qualifier=table_name)
-        h = primary_key_hash(value)
-        h.to_a.each{|k,v| h[SQL::QualifiedIdentifier.new(qualifier, k)] = h.delete(k)}
-        h
+        case key = @primary_key
+        when Symbol
+          {SQL::QualifiedIdentifier.new(qualifier, key) => value}
+        when Array
+          hash = {}
+          key.zip(Array(value)){|k,v| hash[SQL::QualifiedIdentifier.new(qualifier, k)] = v}
+          hash
+        else
+          raise(Error, "#{self} does not have a primary key")
+        end
       end
   
       # Similar to finder, but uses a prepared statement instead of a placeholder
@@ -748,7 +756,7 @@ module Sequel
       # dataset methods that accept arguments, you should use define a
       # method directly inside a #dataset_module block.
       def subset(name, *args, &block)
-        dataset_module.subset(name, *args, &block)
+        def_dataset_method(name){filter(*args, &block)}
       end
       
       # Returns name of primary table for the dataset. If the table for the dataset
@@ -779,7 +787,7 @@ module Sequel
 
       # Return the model instance with the primary key, or raise NoMatchingRow if there is no matching record.
       def with_pk!(pk)
-        with_pk(pk) || raise(NoMatchingRow)
+        with_pk(pk) || raise(NoMatchingRow.new(dataset))
       end
   
       # Add model methods that call dataset methods
@@ -843,7 +851,7 @@ module Sequel
         clear_setter_methods_cache
         columns, bad_columns = columns.partition{|x| NORMAL_METHOD_NAME_REGEXP.match(x.to_s)}
         bad_columns.each{|x| def_bad_column_accessor(x)}
-        im = instance_methods.collect{|x| x.to_s}
+        im = instance_methods.collect(&:to_s)
         columns.each do |column|
           meth = "#{column}="
           overridable_methods_module.module_eval("def #{column}; self[:#{column}] end", __FILE__, __LINE__) unless im.include?(column.to_s)
@@ -891,7 +899,7 @@ module Sequel
       # Get the schema from the database, fall back on checking the columns
       # via the database if that will return inaccurate results or if
       # it raises an error.
-      def get_db_schema(reload = false)
+      def get_db_schema(reload = reload_db_schema?)
         set_columns(nil)
         return nil unless @dataset
         schema_hash = {}
@@ -933,14 +941,14 @@ module Sequel
         end
         schema_hash
       end
-      
+
       # Uncached version of setter_methods, to be overridden by plugins
       # that want to modify the methods used.
       def get_setter_methods
         if allowed_columns
           allowed_columns.map{|x| "#{x}="}
         else
-          meths = instance_methods.collect{|x| x.to_s}.grep(SETTER_METHOD_REGEXP) - RESTRICTED_SETTER_METHODS
+          meths = instance_methods.collect(&:to_s).grep(SETTER_METHOD_REGEXP) - RESTRICTED_SETTER_METHODS
           meths -= Array(primary_key).map{|x| "#{x}="} if primary_key && restrict_primary_key?
           meths
         end
@@ -1045,6 +1053,11 @@ module Sequel
         end
       end
 
+      # Whether to reload the database schema by default, ignoring any cached value.
+      def reload_db_schema?
+        false
+      end
+      
       # Reset the cached fast primary lookup SQL if a simple table and primary key
       # are used, or set it to nil if not used.
       def reset_fast_pk_lookup_sql
@@ -1123,20 +1136,34 @@ module Sequel
       attr_writer(*BOOLEAN_SETTINGS)
 
       # The hash of attribute values.  Keys are symbols with the names of the
-      # underlying database columns.
+      # underlying database columns. The returned hash is a reference to the
+      # receiver's values hash, and modifying it will also modify the receiver's
+      # values.
       #
       #   Artist.new(:name=>'Bob').values # => {:name=>'Bob'}
       #   Artist[1].values # => {:id=>1, :name=>'Jim', ...}
       attr_reader :values
       alias to_hash values
 
+      # Get the value of the column.  Takes a single symbol or string argument.
+      # By default it calls send with the argument to get the value.  This can
+      # be overridden if you have columns that conflict with existing
+      # method names.
+      alias get_column_value send
+
+      # Set the value of the column.  Takes two argument.  The first is a
+      # symbol or string argument for the column name, suffixed with =.  The
+      # second is the value to set for the column.  By default it calls send
+      # with the argument to set the value.  This can be overridden if you have
+      # columns that conflict with existing method names (unlikely for setter
+      # methods, but possible).
+      alias set_column_value send
+
       # Creates new instance and passes the given values to set.
-      # If a block is given, yield the instance to the block unless
-      # from_db is true.
+      # If a block is given, yield the instance to the block.
       #
       # Arguments:
       # values :: should be a hash to pass to set. 
-      # from_db :: only for backwards compatibility, forget it exists.
       #
       #   Artist.new(:name=>'Bob')
       #
@@ -1208,6 +1235,14 @@ module Sequel
       def autoincrementing_primary_key
         primary_key
       end
+
+      # Cancel the current action.  Should be called in before hooks to halt
+      # the processing of the action.  If a +msg+ argument is given and
+      # the model instance is configured to raise exceptions on failure,
+      # sets the message to use for the raised HookFailed exception.
+      def cancel_action(msg=nil)
+        raise_hook_failure(msg)
+      end
   
       # The columns that have been updated.  This isn't completely accurate,
       # as it could contain columns whose values have not changed.
@@ -1296,9 +1331,10 @@ module Sequel
       def freeze
         values.freeze
         changed_columns.freeze
-        errors
-        validate
-        errors.freeze
+        unless errors.frozen?
+          validate
+          errors.freeze
+        end
         this.freeze if !new? && model.primary_key
         super
       end
@@ -1445,6 +1481,16 @@ module Sequel
         model.primary_key_hash(pk)
       end
       
+      # Returns a hash mapping the receivers primary key column(s) to their values.
+      # 
+      #   Artist[1].qualified_pk_hash
+      #   # => {Sequel.qualify(:artists, :id)=>1}
+      #   Artist[[1, 2]].qualified_pk_hash
+      #   # => {Sequel.qualify(:artists, :id1)=>1, Sequel.qualify(:artists, :id2)=>2}
+      def qualified_pk_hash(qualifier=model.table_name)
+        model.qualified_primary_key_hash(pk, qualifier)
+      end
+      
       # Reloads attributes from database and returns self. Also clears all
       # changed_columns information.  Raises an +Error+ if the record no longer
       # exists in the database.
@@ -1515,7 +1561,7 @@ module Sequel
       #   a.save_changes # UPDATE artists SET name = 'Bob' WHERE (id = 1)
       #   # => #<Artist {:id=>1, :name=>'Jim', ...}
       def save_changes(opts=OPTS)
-        save(opts.merge(:changed=>true)) || false if modified? 
+        save(Hash[opts].merge!(:changed=>true)) || false if modified? 
       end
   
       # Updates the instance with the supplied values with support for virtual
@@ -1567,7 +1613,7 @@ module Sequel
       #   # Sequel::Error raised
       def set_fields(hash, fields, opts=nil)
         opts = if opts
-          model.default_set_fields_options.merge(opts)
+          Hash[model.default_set_fields_options].merge!(opts)
         else
           model.default_set_fields_options
         end
@@ -1576,23 +1622,23 @@ module Sequel
         when :skip
           fields.each do |f|
             if hash.has_key?(f) 
-              send("#{f}=", hash[f])
+              set_column_value("#{f}=", hash[f])
             elsif f.is_a?(Symbol) && hash.has_key?(sf = f.to_s)
-              send("#{sf}=", hash[sf])
+              set_column_value("#{sf}=", hash[sf])
             end
           end
         when :raise
           fields.each do |f|
             if hash.has_key?(f)
-              send("#{f}=", hash[f])
+              set_column_value("#{f}=", hash[f])
             elsif f.is_a?(Symbol) && hash.has_key?(sf = f.to_s)
-              send("#{sf}=", hash[sf])
+              set_column_value("#{sf}=", hash[sf])
             else
               raise(Sequel::Error, "missing field in hash: #{f.inspect} not in #{hash.inspect}")
             end
           end
         else
-          fields.each{|f| send("#{f}=", hash[f])}
+          fields.each{|f| set_column_value("#{f}=", hash[f])}
         end
         self
       end
@@ -1631,7 +1677,7 @@ module Sequel
         raise Error, "No dataset for model #{model}" unless ds = model.instance_dataset
 
         cond = if ds.joined_dataset?
-          model.qualified_primary_key_hash(pk)
+          qualified_pk_hash
         else
           pk_hash
         end
@@ -1701,6 +1747,32 @@ module Sequel
 
       private
       
+      # Run code directly after the INSERT query, before after_create.
+      # This is only a temporary API, it should not be overridden by external code.
+      def _after_create(pk)
+        @this = nil
+        @new = false
+        @was_new = true
+      end
+
+      # Run code after around_save returns, before calling after_commit.
+      # This is only a temporary API, it should not be overridden by external code.
+      def _after_save(pk)
+        if @was_new
+          @was_new = nil
+          pk ? _save_refresh : changed_columns.clear
+        else
+          @columns_updated = nil
+        end
+        @modified = false
+      end
+
+      # Run code directly after the UPDATE query, before after_update.
+      # This is only a temporary API, it should not be overridden by external code.
+      def _after_update
+        @this = nil
+      end
+
       # Run code before any validation is done, but also run it before saving
       # even if validation is skipped.  This is a private hook.  It exists so that
       # plugins can set values automatically before validation (as the values
@@ -1729,7 +1801,8 @@ module Sequel
       def _delete_without_checking
         if sql = (m = model).fast_instance_delete_sql
           sql = sql.dup
-          (ds = m.dataset).literal_append(sql, pk)
+          ds = use_server(m.dataset)
+          ds.literal_append(sql, pk)
           ds.with_sql_delete(sql)
         else
           _delete_dataset.delete 
@@ -1787,18 +1860,21 @@ module Sequel
   
       # Insert into the given dataset and return the primary key created (if any).
       def _insert_raw(ds)
-        ds.insert(@values)
+        ds.insert(_insert_values)
       end
 
       # Insert into the given dataset and return the hash of column values.
       def _insert_select_raw(ds)
-        ds.insert_select(@values)
+        ds.insert_select(_insert_values)
       end
+
+      # The values hash to use when inserting a new record.
+      alias _insert_values values
       
       # Refresh using a particular dataset, used inside save to make sure the same server
       # is used for reading newly inserted values from the database
       def _refresh(dataset)
-        _refresh_set_values(_refresh_get(dataset) || raise(Error, "Record not found"))
+        _refresh_set_values(_refresh_get(dataset) || raise(NoExistingObject, "Record not found"))
         changed_columns.clear
       end
 
@@ -1817,7 +1893,6 @@ module Sequel
       def _save(opts)
         sh = {:server=>this_server}
         db.after_rollback(sh){after_rollback} if uacr = use_after_commit_rollback
-        was_new = false
         pk = nil
         called_save = false
         called_cu = false
@@ -1825,14 +1900,11 @@ module Sequel
           called_save = true
           raise_hook_failure(:before_save) if before_save == false
           if new?
-            was_new = true
             around_create do
               called_cu = true
               raise_hook_failure(:before_create) if before_create == false
               pk = _insert
-              @this = nil
-              @new = false
-              @was_new = true
+              _after_create(pk)
               after_create
               true
             end
@@ -1855,7 +1927,7 @@ module Sequel
                 changed_columns.reject!{|c| columns.include?(c)}
               end
               _update_columns(@columns_updated)
-              @this = nil
+              _after_update
               after_update
               true
             end
@@ -1865,22 +1937,16 @@ module Sequel
           true
         end
         raise_hook_failure(:around_save) unless called_save
-        if was_new
-          @was_new = nil
-          pk ? _save_refresh : changed_columns.clear
-        else
-          @columns_updated = nil
-        end
-        @modified = false
+        _after_save(pk)
         db.after_commit(sh){after_commit} if uacr
         self
       end
-
+      
       # Refresh the object after saving it, used to get
       # default values of all columns.  Separated from _save so it
       # can be overridden to avoid the refresh.
       def _save_refresh
-        _save_set_values(_refresh_get(this.opts[:server] ? this : this.server(:default)) || raise(Error, "Record not found"))
+        _save_set_values(_refresh_get(this.server?(:default)) || raise(NoExistingObject, "Record not found"))
         changed_columns.clear
       end
 
@@ -1897,7 +1963,7 @@ module Sequel
       # databases don't like you setting primary key values even
       # to their existing values.
       def _save_update_all_columns_hash
-        v = @values.dup
+        v = Hash[@values]
         Array(primary_key).each{|x| v.delete(x) unless changed_columns.include?(x)}
         v
       end
@@ -1984,7 +2050,7 @@ module Sequel
       
       # If transactions should be used, wrap the yield in a transaction block.
       def checked_transaction(opts=OPTS)
-        use_transaction?(opts) ? db.transaction({:server=>this_server}.merge(opts)){yield} : yield
+        use_transaction?(opts) ? db.transaction({:server=>this_server}.merge!(opts)){yield} : yield
       end
 
       # Change the value of the column to given value, recording the change.
@@ -2022,7 +2088,7 @@ module Sequel
       # Copy constructor -- Duplicate internal data structures.
       def initialize_copy(other)
         super
-        @values = @values.dup
+        @values = Hash[@values]
         @changed_columns = @changed_columns.dup if @changed_columns
         @errors = @errors.dup if @errors
         @this = @this.dup if @this
@@ -2051,8 +2117,17 @@ module Sequel
 
       # Raise an error appropriate to the hook type. May be swallowed by
       # checked_save_failure depending on the raise_on_failure? setting.
-      def raise_hook_failure(type)
-        raise HookFailed.new("the #{type} hook failed", self)
+      def raise_hook_failure(type=nil)
+        msg = case type
+        when String
+          type
+        when Symbol
+          "the #{type} hook failed"
+        else
+          "a hook failed"
+        end
+
+        raise HookFailed.new(msg, self)
       end
   
       # Get the ruby class or classes related to the given column's type.
@@ -2071,17 +2146,17 @@ module Sequel
         hash.each do |k,v|
           m = "#{k}="
           if meths.include?(m)
-            send(m, v)
+            set_column_value(m, v)
           elsif strict
             # Avoid using respond_to? or creating symbols from user input
-            if public_methods.map{|s| s.to_s}.include?(m)
-              if Array(model.primary_key).map{|s| s.to_s}.member?(k.to_s) && model.restrict_primary_key?
-                raise Error, "#{k} is a restricted primary key"
+            if public_methods.map(&:to_s).include?(m)
+              if Array(model.primary_key).map(&:to_s).member?(k.to_s) && model.restrict_primary_key?
+                raise MassAssignmentRestriction, "#{k} is a restricted primary key"
               else
-                raise Error, "#{k} is a restricted column"
+                raise MassAssignmentRestriction, "#{k} is a restricted column"
               end
             else
-              raise Error, "method #{m} doesn't exist"
+              raise MassAssignmentRestriction, "method #{m} doesn't exist"
             end
           end
         end
@@ -2104,7 +2179,7 @@ module Sequel
         if type.is_a?(Array)
           type.map{|x| "#{x}="}
         else
-          meths = methods.collect{|x| x.to_s}.grep(SETTER_METHOD_REGEXP) - RESTRICTED_SETTER_METHODS
+          meths = methods.collect(&:to_s).grep(SETTER_METHOD_REGEXP) - RESTRICTED_SETTER_METHODS
           meths -= Array(primary_key).map{|x| "#{x}="} if type != :all && primary_key && model.restrict_primary_key?
           meths
         end
@@ -2185,7 +2260,7 @@ module Sequel
       #   # DELETE FROM artists WHERE (id = 2)
       #   # ...
       def destroy
-        pr = proc{all{|r| r.destroy}.length}
+        pr = proc{all(&:destroy).length}
         model.use_transactions ? @db.transaction(:server=>opts[:server], &pr) : pr.call
       end
 
@@ -2283,11 +2358,12 @@ module Sequel
       # value.  If no records matches, returns nil.
       #
       #   # Single primary key
-      #   Artist.dataset.with_pk(1) # SELECT * FROM artists WHERE (id = 1) LIMIT 1
+      #   Artist.dataset.with_pk(1)
+      #   # SELECT * FROM artists WHERE (artists.id = 1) LIMIT 1
       #
       #   # Composite primary key
-      #   Artist.dataset.with_pk([1, 2]) # SELECT * FROM artists
-      #                                  # WHERE ((id1 = 1) AND (id2 = 2)) LIMIT 1
+      #   Artist.dataset.with_pk([1, 2])
+      #   # SELECT * FROM artists WHERE ((artists.id1 = 1) AND (artists.id2 = 2)) LIMIT 1
       def with_pk(pk)
         first(model.qualified_primary_key_hash(pk))
       end
@@ -2295,7 +2371,7 @@ module Sequel
       # Same as with_pk, but raises NoMatchingRow instead of returning nil if no
       # row matches.
       def with_pk!(pk)
-        with_pk(pk) || raise(NoMatchingRow)
+        with_pk(pk) || raise(NoMatchingRow.new(self))
       end
     end
 
