@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   # Exception class raised when +raise_on_save_failure+ is set and a before hook returns false
   # or an around hook doesn't call super or yield.
@@ -11,15 +13,19 @@ module Sequel
     end
   end
 
-  # Deprecated alias for HookFailed, kept for backwards compatibility
+  # Alias for HookFailed, kept for backwards compatibility
   BeforeHookFailed = HookFailed
   
   # Exception class raised when +require_modification+ is set and an UPDATE or DELETE statement to modify the dataset doesn't
   # modify a single row.
-  class NoExistingObject < Error; end
+  NoExistingObject = Class.new(Error)
   
   # Raised when an undefined association is used when eager loading.
-  class UndefinedAssociation < Error; end
+  UndefinedAssociation = Class.new(Error)
+
+  # Raised when a mass assignment method is called in strict mode with either a restricted column
+  # or a column without a setter method.
+  MassAssignmentRestriction = Class.new(Error)
   
   # Exception class raised when +raise_on_save_failure+ is set and validation fails
   class ValidationFailed < Error
@@ -43,4 +49,9 @@ module Sequel
       end
     end
   end
+
+  # Call name on each class to set the name for the class, so it gets cached.
+  constants.map{|c| const_get(c)}.each do |c|
+    Class === c && c.name
+  end
 end
