@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   module Plugins
     # DatasetAssociations allows you to easily use your model associations
@@ -17,12 +19,10 @@ module Sequel
     #   #   WHERE ((id >= 1) AND (id <= 100))))
     # 
     # This works for all of the association types that ship with Sequel,
-    # including the many_through_many type.  Most association options that
+    # including ones implemented in other plugins.  Most association options that
     # are supported when eager loading are supported when using a
-    # dataset association.  However, associations that use :limit or
-    # one_to_one associations that are really one_to_many relationships
-    # in the database will not work correctly, returning all associated
-    # objects.
+    # dataset association. However, it will only work for limited associations or
+    # *_one associations with orders if the database supports window functions.
     #
     # As the dataset methods return datasets, you can easily chain the
     # methods to get associated datasets of associated datasets:
@@ -66,10 +66,9 @@ module Sequel
         # such that it would return the union of calling the association method on
         # all objects returned by the current dataset.
         #
-        # This supports most options that are supported when eager loading.  It doesn't
-        # support limits on the associations, or one_to_one associations that are really
-        # one_to_many and use an order to select the first matching object.  In both of
-        # those cases, this will return an array of all matching objects.
+        # This supports most options that are supported when eager loading.  However, it
+        # will only work for limited associations or *_one associations with orders if the
+        # database supports window functions.
         def associated(name)
           raise Error, "unrecognized association name: #{name.inspect}" unless r = model.association_reflection(name)
           ds = r.associated_class.dataset
@@ -78,17 +77,23 @@ module Sequel
           when :many_to_one
             ds.filter(r.qualified_primary_key=>sds.select(*Array(r[:qualified_key])))
           when :one_to_one, :one_to_many
-            ds.filter(r.qualified_key=>sds.select(*Array(r.qualified_primary_key)))
-          when :many_to_many
-            ds.filter(r.qualified_right_primary_key=>sds.select(*Array(r.qualified_right_key)).
-              join(r[:join_table], r[:left_keys].zip(r[:left_primary_keys]), :implicit_qualifier=>model.table_name))
-          when :many_through_many
+            r.send(:apply_filter_by_associations_limit_strategy, ds.filter(r.qualified_key=>sds.select(*Array(r.qualified_primary_key))))
+          when :many_to_many, :one_through_one
+            mds = r.associated_class.dataset.
+              join(r[:join_table], r[:right_keys].zip(r.right_primary_keys)).
+              select(*Array(r.qualified_right_key)).
+              where(r.qualify(r.join_table_alias, r[:left_keys])=>sds.select(*r.qualify(model.table_name, r[:left_primary_key_columns])))
+            ds.filter(r.qualified_right_primary_key=>r.send(:apply_filter_by_associations_limit_strategy, mds))
+          when :many_through_many, :one_through_many
             fre = r.reverse_edges.first
             fe, *edges = r.edges
-            sds = sds.select(*Array(r.qualify(fre[:table], fre[:left]))).
-              join(fe[:table], Array(fe[:right]).zip(Array(fe[:left])), :implicit_qualifier=>model.table_name)
-            edges.each{|e| sds = sds.join(e[:table], Array(e[:right]).zip(Array(e[:left])))}
-            ds.filter(r.qualified_right_primary_key=>sds)
+            edges << r.final_edge
+            mds = model.
+              select(*Array(r.qualify(fre[:table], fre[:left]))).
+              join(fe[:table], Array(fe[:right]).zip(Array(fe[:left])), :implicit_qualifier=>model.table_name).
+              where(r.qualify(fe[:table], fe[:right])=>sds.select(*r.qualify(model.table_name, r[:left_primary_key_columns])))
+            edges.each{|e| mds = mds.join(e[:table], Array(e[:right]).zip(Array(e[:left])))}
+            ds.filter(r.qualified_right_primary_key=>r.send(:apply_filter_by_associations_limit_strategy, mds))
           when :pg_array_to_many
             ds.filter(Sequel.expr(r.primary_key=>sds.select{Sequel.pg_array_op(r.qualify(r[:model].table_name, r[:key])).unnest}))
           when :many_to_pg_array
@@ -96,9 +101,7 @@ module Sequel
           else
             raise Error, "unrecognized association type for association #{name.inspect}: #{r[:type].inspect}"
           end
-          ds = model.apply_association_dataset_opts(r, ds)
-          r[:extend].each{|m| ds.extend(m)}
-          ds
+          r.apply_eager_dataset_changes(ds).unlimited
         end
       end
     end
