@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   module Plugins
     # This plugin allows you to add filters on a per object basis that
@@ -84,6 +86,13 @@ module Sequel
           end
         end
 
+        # Duplicate internal structures when duplicating model instance.
+        def initialize_copy(other)
+          super
+          @instance_filters = other.send(:instance_filters).dup
+          self
+        end
+      
         # Lazily initialize the instance filter array.
         def instance_filters
           @instance_filters ||= []
