@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 require 'json'
 
 module Sequel
@@ -36,6 +38,12 @@ module Sequel
     #   album.to_json(:root => true)
     #   # => '{"album":{"id":1,"name":"RF","artist_id":2}}'
     #
+    # You can specify JSON serialization options to use later:
+    #
+    #   album.json_serializer_opts(:root => true)
+    #   [album].to_json
+    #   # => '[{"album":{"id":1,"name":"RF","artist_id":2}}]'
+    #
     # Additionally, +to_json+ also exists as a class and dataset method, both
     # of which return all objects in the dataset:
     #
@@ -239,6 +247,20 @@ module Sequel
           self
         end
 
+        # Set the json serialization options that will be used by default
+        # in future calls to +to_json+.  This is designed for cases where
+        # the model object will be used inside another data structure
+        # which to_json is called on, and as such will not allow passing
+        # of arguments to +to_json+.
+        #
+        # Example:
+        #
+        #   obj.json_serializer_opts(:only=>:name)
+        #   [obj].to_json # => '[{"name":"..."}]'
+        def json_serializer_opts(opts=OPTS)
+          @json_serializer_opts = Hash[@json_serializer_opts||OPTS].merge!(opts)
+        end
+
         # Return a string in JSON format.  Accepts the following
         # options:
         #
@@ -253,14 +275,17 @@ module Sequel
         # :only :: Symbol or Array of Symbols of columns to only
         #          include in the JSON output, ignoring all other
         #          columns.
-        # :root :: Qualify the JSON with the name of the object.
+        # :root :: Qualify the JSON with the name of the object.  If a
+        #          string is given, use the string as the key, otherwise
+        #          use an underscored version of the model's name.
         def to_json(*a)
-          if opts = a.first.is_a?(Hash)
-            opts = model.json_serializer_opts.merge(a.first)
+          opts = model.json_serializer_opts
+          opts = Hash[opts].merge!(@json_serializer_opts) if @json_serializer_opts
+          if (arg_opts = a.first).is_a?(Hash)
+            opts = Hash[opts].merge!(arg_opts)
             a = []
-          else
-            opts = model.json_serializer_opts
           end
+
           vals = values
           cols = if only = opts[:only]
             Array(only)
@@ -270,7 +295,7 @@ module Sequel
 
           h = {}
 
-          cols.each{|c| h[c.to_s] = send(c)}
+          cols.each{|c| h[c.to_s] = get_column_value(c)}
           if inc = opts[:include]
             if inc.is_a?(Hash)
               inc.each do |k, v|
@@ -286,7 +311,14 @@ module Sequel
               Array(inc).each{|c| h[c.to_s] = send(c)}
             end
           end
-          h = {model.send(:underscore, model.to_s) => h} if opts[:root]
+
+          if root = opts[:root]
+            unless root.is_a?(String)
+              root = model.send(:underscore, model.send(:demodulize, model.to_s))
+            end
+            h = {root => h}
+          end
+
           Sequel.object_to_json(h, *a)
         end
       end
@@ -299,16 +331,13 @@ module Sequel
         #
         # :array :: An array of instances.  If this is not provided,
         #           calls #all on the receiver to get the array.
-        # :root :: If set to :collection, only wraps the collection
-        #          in a root object.  If set to :instance, only wraps
+        # :root :: If set to :collection, wraps the collection
+        #          in a root object using the pluralized, underscored model
+        #          name as the key.  If set to :instance, only wraps
         #          the instances in a root object.  If set to :both,
         #          wraps both the collection and instances in a root
-        #          object.  Unfortunately, for backwards compatibility,
-        #          if this option is true and doesn't match one of those
-        #          symbols, it defaults to both.  That may change in a
-        #          future version, so for forwards compatibility, you
-        #          should pick a specific symbol for your desired
-        #          behavior.
+        #          object.  If set to a string, wraps the collection in
+        #          a root object using the string as the key.  
         def to_json(*a)
           if opts = a.first.is_a?(Hash)
             opts = model.json_serializer_opts.merge(a.first)
@@ -317,15 +346,17 @@ module Sequel
             opts = model.json_serializer_opts
           end
 
-          collection_root = case opts[:root]
+          case collection_root = opts[:root]
           when nil, false, :instance
-            false
-          when :both
-            true
+            collection_root = false
           else
             opts = opts.dup
-            opts.delete(:root)
-            true
+            unless collection_root == :both
+              opts.delete(:root)
+            end
+            unless collection_root.is_a?(String)
+              collection_root = model.send(:pluralize, model.send(:underscore, model.send(:demodulize, model.to_s)))
+            end
           end
 
           res = if row_proc 
@@ -341,7 +372,7 @@ module Sequel
           end
 
           if collection_root
-            Sequel.object_to_json({model.send(:pluralize, model.send(:underscore, model.to_s)) => res}, *a)
+            Sequel.object_to_json({collection_root => res}, *a)
           else
             Sequel.object_to_json(res, *a)
           end
