@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   module Plugins
     # The lazy_attributes plugin allows users to easily set that some attributes
@@ -83,7 +85,7 @@ module Sequel
           end
 
           if base_ds = opts[:dataset]
-            ds = base_ds.where(model.qualified_primary_key_hash(pk, table))
+            ds = base_ds.where(qualified_pk_hash(table))
           else
             base_ds = model.dataset
             ds = this
