@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   module Plugins
     # The nested_attributes plugin allows you to create, update, and delete
@@ -37,14 +39,16 @@ module Sequel
     # of creating a new album.
     #
     # If you would like to delete the associated object instead of updating it, you add a _delete
-    # entry to the hash:
+    # entry to the hash, and also pass the :destroy option when calling +nested_attributes+:
     #
+    #   Artist.nested_attributes :albums, :destroy=>true
     #   a.update(:albums_attributes => [{:id=>1, :_delete=>true}])
     #
     # This will delete the related associated object from the database.  If you want to leave the
     # associated object in the database, but just remove it from the association, add a _remove
-    # entry in the hash:
+    # entry in the hash, and also pass the :remove option when calling +nested_attributes+:
     #
+    #   Artist.nested_attributes :albums, :remove=>true
     #   a.update(:albums_attributes => [{:id=>1, :_remove=>true}])
     #
     # The above example was for a one_to_many association, but the plugin also works similarly
@@ -71,9 +75,9 @@ module Sequel
     # To save changes to the artist, create the first album and associate it to the artist,
     # and update the other existing associated album.
     module NestedAttributes
-      # Depend on the instance_hooks plugin.
+      # Depend on the validate_associated plugin.
       def self.apply(model)
-        model.plugin(:instance_hooks)
+        model.plugin(:validate_associated)
       end
       
       module ClassMethods
@@ -137,7 +141,7 @@ module Sequel
         def set_nested_attributes(assoc, obj, opts=OPTS)
           raise(Error, "no association named #{assoc} for #{model.inspect}") unless ref = model.association_reflection(assoc)
           raise(Error, "nested attributes are not enabled for association #{assoc} for #{model.inspect}") unless meta = ref[:nested_attributes]
-          meta = meta.merge(opts)
+          meta = Hash[meta].merge!(opts)
           meta[:reflection] = ref
           if ref.returns_array?
             nested_attributes_list_setter(meta, obj)
@@ -152,9 +156,9 @@ module Sequel
         # not use an ensure block, so callers should be careful.
         def nested_attributes_check_key_modifications(meta, obj)
           reflection = meta[:reflection]
-          keys = reflection.associated_object_keys.map{|x| obj.send(x)}
+          keys = reflection.associated_object_keys.map{|x| obj.get_column_value(x)}
           yield
-          unless keys == reflection.associated_object_keys.map{|x| obj.send(x)}
+          unless keys == reflection.associated_object_keys.map{|x| obj.get_column_value(x)}
             raise(Error, "Modifying association dependent key(s) when updating associated objects is not allowed")
           end
         end
@@ -166,7 +170,7 @@ module Sequel
           reflection = meta[:reflection]
           obj = reflection.associated_class.new
           nested_attributes_set_attributes(meta, obj, attributes)
-          after_validation_hook{validate_associated_object(meta, obj)}
+          delay_validate_associated_object(reflection, obj)
           if reflection.returns_array?
             send(reflection[:name]) << obj
             after_save_hook{send(reflection.add_method, obj)}
@@ -195,7 +199,7 @@ module Sequel
         # If there is a limit on the nested attributes for this association,
         # make sure the length of the attributes_list is not greater than the limit.
         def nested_attributes_list_setter(meta, attributes_list)
-          attributes_list = attributes_list.sort_by{|x| x.to_s}.map{|k,v| v} if attributes_list.is_a?(Hash)
+          attributes_list = attributes_list.sort_by(&:to_s).map{|k,v| v} if attributes_list.is_a?(Hash)
           if (limit = meta[:limit]) && attributes_list.length > limit
             raise(Error, "number of nested attributes (#{attributes_list.length}) exceeds the limit (#{limit})")
           end
@@ -254,10 +258,10 @@ module Sequel
           reflection = meta[:reflection]
           klass = reflection.associated_class
           sym_keys = Array(klass.primary_key)
-          str_keys = sym_keys.map{|k| k.to_s}
+          str_keys = sym_keys.map(&:to_s)
           if (pk = attributes.values_at(*sym_keys)).all? || (pk = attributes.values_at(*str_keys)).all?
-            pk = pk.map{|k| k.to_s}
-            obj = Array(send(reflection[:name])).find{|x| Array(x.pk).map{|k| k.to_s} == pk}
+            pk = pk.map(&:to_s)
+            obj = Array(send(reflection[:name])).find{|x| Array(x.pk).map(&:to_s) == pk}
           end
           if obj
             attributes = attributes.dup.delete_if{|k,v| str_keys.include? k.to_s}
@@ -282,7 +286,7 @@ module Sequel
         # Returns the object updated.
         def nested_attributes_update(meta, obj, attributes)
           nested_attributes_update_attributes(meta, obj, attributes)
-          after_validation_hook{validate_associated_object(meta, obj)}
+          delay_validate_associated_object(meta[:reflection], obj)
           # Don't need to validate the object twice if :validate association option is not false
           # and don't want to validate it at all if it is false.
           after_save_hook{obj.save_changes(:validate=>false)}
@@ -295,28 +299,6 @@ module Sequel
             nested_attributes_set_attributes(meta, obj, attributes)
           end
         end
-
-        # Validate the given associated object, adding any validation error messages from the
-        # given object to the parent object.
-        def validate_associated_object(meta, obj)
-          reflection = meta[:reflection]
-          return if reflection[:validate] == false
-          association = reflection[:name]
-          if (reflection[:type] == :one_to_many || reflection[:type] == :one_to_one) && (key = reflection[:key]).is_a?(Symbol) && !(pk_val = obj.values[key])
-            # There could be a presence validation on the foreign key in the associated model,
-            # which will fail if we validate before saving the current object.  If there is
-            # no value for the foreign key, set it to the current primary key value, or a dummy
-            # value of 0 if we haven't saved the current object.
-            p_key = pk unless pk.is_a?(Array)
-            obj.values[key] = p_key || 0
-            key = nil if p_key
-          end
-          obj.errors.full_messages.each{|m| errors.add(association, m)} unless obj.valid?
-          if key && !pk_val
-            # If we used a dummy value of 0, remove it so it doesn't accidently remain.
-            obj.values.delete(key)
-          end
-        end
       end
     end
   end
