@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   module Plugins
     # The prepared_statements_safe plugin modifies the model to reduce the number of
@@ -57,7 +59,7 @@ module Sequel
         # of free columns.
         def before_create
           if v = model.prepared_statements_column_defaults
-            @values = v.merge(values)
+            @values = Hash[v].merge!(values)
           end
           super
         end
