@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   module Plugins
     # = Overview
@@ -148,7 +150,7 @@ module Sequel
         a[:read_only] = true unless a.has_key?(:read_only)
         a[:eager_loader_key] = key
         a[:dataset] ||= proc do
-          base_ds = model.filter(prkey_array.zip(key_array.map{|k| send(k)}))
+          base_ds = model.filter(prkey_array.zip(key_array.map{|k| get_column_value(k)}))
           recursive_ds = model.join(t, key_array.zip(prkey_array))
           if c = a[:conditions]
             (base_ds, recursive_ds) = [base_ds, recursive_ds].collect do |ds|
@@ -243,7 +245,7 @@ module Sequel
         d[:read_only] = true unless d.has_key?(:read_only)
         la = d[:level_alias] ||= :x_level_x
         d[:dataset] ||= proc do
-          base_ds = model.filter(key_array.zip(prkey_array.map{|k| send(k)}))
+          base_ds = model.filter(key_array.zip(prkey_array.map{|k| get_column_value(k)}))
           recursive_ds = model.join(t, prkey_array.zip(key_array))
           if c = d[:conditions]
             (base_ds, recursive_ds) = [base_ds, recursive_ds].collect do |ds|
@@ -272,7 +274,11 @@ module Sequel
               end
             end
             children_map.each do |parent_id, objs|
-              parent_map[parent_id].associations[childrena] = objs
+              parent_obj = parent_map[parent_id]
+              parent_obj.associations[childrena] = objs
+              objs.each do |obj|
+                obj.associations[parent] = parent_obj
+              end
             end
           end
         end
@@ -333,7 +339,12 @@ module Sequel
             (children_map[key_conv[obj]] ||= []) << obj
           end
           children_map.each do |parent_id, objs|
-            parent_map[parent_id].associations[childrena] = objs.uniq
+            objs = objs.uniq
+            parent_obj = parent_map[parent_id]
+            parent_obj.associations[childrena] = objs
+            objs.each do |obj|
+              obj.associations[parent] = parent_obj
+            end
           end
         end
         model.one_to_many descendants, d
