@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   module Plugins
     # Sequel's built in Serialization plugin allows you to keep serialized
@@ -36,8 +38,8 @@ module Sequel
     #   # Register custom serializer/deserializer pair, if desired
     #   require 'sequel/plugins/serialization'
     #   Sequel::Plugins::Serialization.register_format(:reverse,
-    #     lambda{|v| v.reverse},
-    #     lambda{|v| v.reverse})
+    #     lambda(&:reverse),
+    #     lambda(&:reverse))
     #
     #   class User < Sequel::Model
     #     # Built-in format support when loading the plugin
@@ -51,7 +53,7 @@ module Sequel
     #     serialize_attributes :reverse, :password
     #
     #     # Use a custom serializer/deserializer pair without registering
-    #     serialize_attributes [lambda{|v| v.reverse}, lambda{|v| v.reverse}], :password
+    #     serialize_attributes [lambda(&:reverse), lambda(&:reverse)], :password
     #   end
     #   user = User.create
     #   user.permissions = { :global => 'read-only' }
@@ -106,7 +108,7 @@ module Sequel
             end
           end
         end)
-      register_format(:yaml, lambda{|v| v.to_yaml}, lambda{|v| YAML.load(v)})
+      register_format(:yaml, lambda(&:to_yaml), lambda{|v| YAML.load(v)})
       register_format(:json, lambda{|v| Sequel.object_to_json(v)}, lambda{|v| Sequel.parse_json(v)})
 
       module ClassMethods
@@ -129,7 +131,7 @@ module Sequel
         def serialize_attributes(format, *columns)
           if format.is_a?(Symbol)
             unless format = REGISTERED_FORMATS[format]
-              raise(Error, "Unsupported serialization format: #{format} (valid formats: #{REGISTERED_FORMATS.keys.map{|k| k.inspect}.join})")
+              raise(Error, "Unsupported serialization format: #{format} (valid formats: #{REGISTERED_FORMATS.keys.map(&:inspect).join})")
             end
           end
           serializer, deserializer = format
@@ -163,8 +165,10 @@ module Sequel
                 end
               end
               define_method("#{column}=") do |v| 
-                if !changed_columns.include?(column) && (new? || send(column) != v)
+                if !changed_columns.include?(column) && (new? || get_column_value(column) != v)
                   changed_columns << column
+
+                  will_change_column(column) if respond_to?(:will_change_column)
                 end
 
                 deserialized_values[column] = v
@@ -212,7 +216,7 @@ module Sequel
         # Dup the deserialized values when duping model instance.
         def initialize_copy(other)
           super
-          @deserialized_values = other.deserialized_values.dup
+          @deserialized_values = Hash[other.deserialized_values]
           self
         end
 
