@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   module Plugins
     # The sharding plugin augments Sequel's default model sharding support
@@ -30,10 +32,12 @@ module Sequel
             eb = eo[:eager_block]
             set_server = proc do |ds|
               ds = eb.call(ds) if eb
-              ds = ds.server(server) unless ds.opts[:server]
+              ds = ds.server?(server)
               ds
             end
-            eo = eo.merge(:eager_block=>set_server)
+            eo = Hash[eo]
+            eo[:eager_block] = set_server
+            eo
           end
 
           super
@@ -53,7 +57,7 @@ module Sequel
         def eager_graph_dataset(opts, eager_options)
           ds = super
           if s = eager_options[:self].opts[:server]
-            ds = ds.server(s) unless ds.opts[:server]
+            ds = ds.server?(s)
           end
           ds
         end
