@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   extension :blank
 
@@ -103,9 +105,9 @@ module Sequel
           validations.each do |att, procs|
             v = case att
             when Array
-              att.collect{|a| o.send(a)}
+              att.collect{|a| o.get_column_value(a)}
             else
-              o.send(att)
+              o.get_column_value(att)
             end
             procs.each {|tag, p| p.call(o, att, v)}
           end
@@ -150,7 +152,7 @@ module Sequel
           reflect_validation(:confirmation, opts, atts)
           atts << opts
           validates_each(*atts) do |o, a, v|
-            o.errors.add(a, opts[:message]) unless v == o.send(:"#{a}_confirmation")
+            o.errors.add(a, opts[:message]) unless v == o.get_column_value(:"#{a}_confirmation")
           end
         end
     
@@ -182,8 +184,8 @@ module Sequel
           blk = if (i = opts[:if]) || (am = opts[:allow_missing]) || (an = opts[:allow_nil]) || (ab = opts[:allow_blank])
             proc do |o,a,v|
               next if i && !validation_if_proc(o, i)
-              next if an && Array(v).all?{|x| x.nil?}
-              next if ab && Array(v).all?{|x| x.blank?}
+              next if an && Array(v).all?(&:nil?)
+              next if ab && Array(v).all?(&:blank?)
               next if am && Array(a).all?{|x| !o.values.has_key?(x)}
               block.call(o,a,v)
             end
@@ -418,7 +420,7 @@ module Sequel
         def validation_if_proc(o, i)
           case i
           when Symbol
-            o.send(i)
+            o.get_column_value(i)
           when Proc
             o.instance_eval(&i)
           else
