@@ -1,3 +1,5 @@
+# frozen-string-literal: true
+
 module Sequel
   module Plugins
     # The validation_helpers plugin contains instance method equivalents for most of the legacy
@@ -30,6 +32,9 @@ module Sequel
     #                   Sequel will attempt to insert a NULL value into the database, instead of using the
     #                   database's default.
     # :allow_nil :: Whether to skip the validation if the value is nil.
+    # :from :: Set to :values to pull column values from the values hash instead of calling the related method.
+    #          Allows for setting up methods on the underlying column values, in the cases where the model
+    #          transforms the underlying value before returning it, such as when using serialization.
     # :message :: The message to use.  Can be a string which is used directly, or a
     #             proc which is called.  If the validation method takes a argument before the array of attributes,
     #             that argument is passed as an argument to the proc.
@@ -156,7 +161,7 @@ module Sequel
         def validates_schema_types(atts=keys, opts=OPTS)
           Array(atts).each do |k|
             if type = schema_type_class(k)
-              validates_type(type, k, {:allow_nil=>true}.merge(opts))
+              validates_type(type, k, {:allow_nil=>true}.merge!(opts))
             end
           end
         end
@@ -211,7 +216,7 @@ module Sequel
         #           a modified dataset that is filtered to include only rows with
         #           the same values as the current object for each column in the array.
         #
-        # If you want to to a case insensitive uniqueness validation on a database that
+        # If you want to do a case insensitive uniqueness validation on a database that
         # is case sensitive by default, you can use:
         #
         #   validates_unique :column, :where=>(proc do |ds, obj, cols|
@@ -224,9 +229,10 @@ module Sequel
         def validates_unique(*atts)
           opts = default_validation_helpers_options(:unique)
           if atts.last.is_a?(Hash)
-            opts = opts.merge(atts.pop)
+            opts = Hash[opts].merge!(atts.pop)
           end
           message = validation_error_message(opts[:message])
+          from_values = opts[:from] == :values
           where = opts[:where]
           atts.each do |a|
             arr = Array(a)
@@ -236,12 +242,15 @@ module Sequel
             ds = if where
               where.call(ds, self, arr)
             else
-              vals = arr.map{|x| send(x)}
-              next if vals.any?{|v| v.nil?}
+              vals = arr.map{|x| from_values ? values[x] : get_column_value(x)}
+              next if vals.any?(&:nil?)
               ds.where(arr.zip(vals))
             end
             ds = yield(ds) if block_given?
-            ds = ds.exclude(pk_hash) unless new?
+            unless new?
+              h = ds.joined_dataset? ? qualified_pk_hash : pk_hash
+              ds = ds.exclude(h)
+            end
             errors.add(a, message) unless ds.count == 0
           end
         end
@@ -262,9 +271,10 @@ module Sequel
         # an error message for that attributes.
         def validatable_attributes(atts, opts)
           am, an, ab, m = opts.values_at(:allow_missing, :allow_nil, :allow_blank, :message)
+          from_values = opts[:from] == :values
           Array(atts).each do |a|
             next if am && !values.has_key?(a)
-            v = send(a)
+            v = from_values ? values[a] : get_column_value(a)
             next if an && v.nil?
             next if ab && v.respond_to?(:blank?) && v.blank?
             if message = yield(a, v, m)
@@ -276,7 +286,7 @@ module Sequel
         # Merge the given options with the default options for the given type
         # and call validatable_attributes with the merged options.
         def validatable_attributes_for_type(type, atts, opts, &block)
-          validatable_attributes(atts, default_validation_helpers_options(type).merge(opts), &block)
+          validatable_attributes(atts, Hash[default_validation_helpers_options(type)].merge!(opts), &block)
         end
         
         # The validation error message to use, as a string.  If message
