@@ -325,12 +325,6 @@ describe "Joined MySQL dataset" do
     @ds.join(:attributes, :node_id => :id).sql.must_equal "SELECT * FROM `nodes` INNER JOIN `attributes` ON (`attributes`.`node_id` = `nodes`.`id`)"
   end
 
-  it "should allow a having clause on ungrouped datasets" do
-    @ds.having('blah')
-
-    @ds.having('blah').sql.must_equal "SELECT * FROM `nodes` HAVING (blah)"
-  end
-
   it "should put a having clause before an order by clause" do
     @ds.order(:aaa).having(:bbb => :ccc).sql.must_equal "SELECT * FROM `nodes` HAVING (`bbb` = `ccc`) ORDER BY `aaa`"
   end
@@ -1289,3 +1283,37 @@ if DB.adapter_scheme == :mysql2
     end
   end
 end
+
+describe "MySQL joined datasets" do
+  before do
+    @db = DB
+    @db.create_table!(:a) do
+      Integer :id
+    end
+    @db.create_table!(:b) do
+      Integer :id
+      Integer :a_id
+    end
+    @db[:a].insert(1)
+    @db[:a].insert(2)
+    @db[:b].insert(3, 1)
+    @db[:b].insert(4, 1)
+    @db[:b].insert(5, 2)
+    @ds = @db[:a].join(:b, :a_id=>:id)
+  end
+  after do
+    @db.drop_table?(:a, :b)
+  end
+
+  it "should support deletions from a single table" do
+    @ds.where(:a__id=>1).delete
+    @db[:a].select_order_map(:id).must_equal [2]
+    @db[:b].select_order_map(:id).must_equal [3, 4, 5]
+  end
+
+  it "should support deletions from multiple tables" do
+    @ds.delete_from(:a, :b).where(:a__id=>1).delete
+    @db[:a].select_order_map(:id).must_equal [2]
+    @db[:b].select_order_map(:id).must_equal [5]
+  end
+end
