@@ -8,20 +8,20 @@ describe "current_datetime_timestamp extension" do
     Sequel.datetime_class = Time
   end
 
-  specify "should have current_timestamp respect Sequel.datetime_class" do
+  it "should have current_timestamp respect Sequel.datetime_class" do
     t = Sequel::Dataset.new(nil).current_datetime 
-    t.should be_a_kind_of(Time)
-    (Time.now - t < 0.1).should == true
+    t.must_be_kind_of(Time)
+    (Time.now - t < 0.1).must_equal true
 
     Sequel.datetime_class = DateTime
     t = Sequel::Dataset.new(nil).current_datetime 
-    t.should be_a_kind_of(DateTime)
-    (DateTime.now - t < (0.1/86400)).should == true
+    t.must_be_kind_of(DateTime)
+    (DateTime.now - t < (0.1/86400)).must_equal true
   end
 
-  specify "should have current_timestamp value be literalized as CURRENT_TIMESTAMP" do
-    @ds.literal(@ds.current_datetime).should == 'CURRENT_TIMESTAMP'
+  it "should have current_timestamp value be literalized as CURRENT_TIMESTAMP" do
+    @ds.literal(@ds.current_datetime).must_equal 'CURRENT_TIMESTAMP'
     Sequel.datetime_class = DateTime
-    @ds.literal(@ds.current_datetime).should == 'CURRENT_TIMESTAMP'
+    @ds.literal(@ds.current_datetime).must_equal 'CURRENT_TIMESTAMP'
   end
 end
