@@ -31,9 +31,20 @@ describe "Sequel::Schema::Generator dump methods" do
       instance_eval(g.dump_constraints, __FILE__, __LINE__)
       instance_eval(g.dump_indexes, __FILE__, __LINE__)
     end
-    g.columns.should == g2.columns
-    g.constraints.should == g2.constraints
-    g.indexes.should == g2.indexes
+    g.columns.must_equal g2.columns
+    g.constraints.must_equal g2.constraints
+    g.indexes.must_equal g2.indexes
+  end
+
+  it "should respect :keep_order option to primary_key" do
+    g = @g.new(@d) do
+      Integer :a
+      primary_key :c, :keep_order=>true
+    end
+    g2 = @g.new(@d) do
+      instance_eval(g.dump_columns, __FILE__, __LINE__)
+    end
+    g.columns.must_equal g2.columns
   end
 
   it "should allow dumping indexes as separate add_index and drop_index methods" do
@@ -43,13 +54,13 @@ describe "Sequel::Schema::Generator dump methods" do
       index [:b, :c], :unique=>true
     end
 
-    g.dump_indexes(:add_index=>:t).should == (<<END_CODE).strip
+    g.dump_indexes(:add_index=>:t).must_equal((<<END_CODE).strip)
 add_index :t, [:a]
 add_index :t, [:c, :e], :name=>:blah
 add_index :t, [:b, :c], :unique=>true
 END_CODE
 
-    g.dump_indexes(:drop_index=>:t).should == (<<END_CODE).strip
+    g.dump_indexes(:drop_index=>:t).must_equal((<<END_CODE).strip)
 drop_index :t, [:b, :c], :unique=>true
 drop_index :t, [:c, :e], :name=>:blah
 drop_index :t, [:a]
@@ -57,7 +68,7 @@ END_CODE
   end
 
   it "should raise an error if you try to dump a Generator that uses a constraint with a proc" do
-    proc{@g.new(@d){check{a>1}}.dump_constraints}.should raise_error(Sequel::Error)
+    proc{@g.new(@d){check{a>1}}.dump_constraints}.must_raise(Sequel::Error)
   end
 end
 
@@ -68,11 +79,14 @@ describe "Sequel::Database dump methods" do
     @d.meta_def(:schema) do |t, *o|
       case t
       when :t1, 't__t1', Sequel.identifier(:t__t1)
-        [[:c1, {:db_type=>'integer', :primary_key=>true, :allow_null=>false}],
+        [[:c1, {:db_type=>'integer', :primary_key=>true, :auto_increment=>true, :allow_null=>false}],
          [:c2, {:db_type=>'varchar(20)', :allow_null=>true}]]
       when :t2
         [[:c1, {:db_type=>'integer', :primary_key=>true, :allow_null=>false}],
          [:c2, {:db_type=>'numeric', :primary_key=>true, :allow_null=>false}]]
+      when :t3
+        [[:c2, {:db_type=>'varchar(20)', :allow_null=>true}],
+         [:c1, {:db_type=>'integer', :primary_key=>true, :auto_increment=>true, :allow_null=>false}]]
       when :t5
         [[:c1, {:db_type=>'blahblah', :allow_null=>true}]]
       end
@@ -80,37 +94,41 @@ describe "Sequel::Database dump methods" do
   end
 
   it "should support dumping table schemas as create_table method calls" do
-    @d.dump_table_schema(:t1).should == "create_table(:t1) do\n  primary_key :c1\n  String :c2, :size=>20\nend"
+    @d.dump_table_schema(:t1).must_equal "create_table(:t1) do\n  primary_key :c1\n  String :c2, :size=>20\nend"
   end
 
   it "should support dumping table schemas when given a string" do
-    @d.dump_table_schema('t__t1').should == "create_table(\"t__t1\") do\n  primary_key :c1\n  String :c2, :size=>20\nend"
+    @d.dump_table_schema('t__t1').must_equal "create_table(\"t__t1\") do\n  primary_key :c1\n  String :c2, :size=>20\nend"
   end
 
   it "should support dumping table schemas when given an identifier" do
-    @d.dump_table_schema(Sequel.identifier(:t__t1)).should == "create_table(\"t__t1\") do\n  primary_key :c1\n  String :c2, :size=>20\nend"
+    @d.dump_table_schema(Sequel.identifier(:t__t1)).must_equal "create_table(\"t__t1\") do\n  primary_key :c1\n  String :c2, :size=>20\nend"
   end
 
   it "should dump non-Integer primary key columns with explicit :type" do
-    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'bigint', :primary_key=>true, :allow_null=>true}]]}
-    @d.dump_table_schema(:t6).should == "create_table(:t6) do\n  primary_key :c1, :type=>Bignum\nend"
+    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'bigint', :primary_key=>true, :allow_null=>true, :auto_increment=>true}]]}
+    @d.dump_table_schema(:t6).must_equal "create_table(:t6) do\n  primary_key :c1, :type=>Bignum\nend"
+  end
+
+  it "should dump auto incrementing primary keys with :keep_order option if they are not first" do
+    @d.dump_table_schema(:t3).must_equal "create_table(:t3) do\n  String :c2, :size=>20\n  primary_key :c1, :keep_order=>true\nend"
   end
 
   it "should handle foreign keys" do
     @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'integer', :allow_null=>true}]]}
     @d.meta_def(:supports_foreign_key_parsing?){true}
     @d.meta_def(:foreign_key_list){|*s| [{:columns=>[:c1], :table=>:t2, :key=>[:c2]}]}
-    @d.dump_table_schema(:t6).should == "create_table(:t6) do\n  foreign_key :c1, :t2, :key=>[:c2]\nend"
+    @d.dump_table_schema(:t6).must_equal "create_table(:t6) do\n  foreign_key :c1, :t2, :key=>[:c2]\nend"
   end
 
   it "should handle primary keys that are also foreign keys" do
-    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'integer', :primary_key=>true, :allow_null=>true}]]}
+    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'integer', :primary_key=>true, :allow_null=>true, :auto_increment=>true}]]}
     @d.meta_def(:supports_foreign_key_parsing?){true}
     @d.meta_def(:foreign_key_list){|*s| [{:columns=>[:c1], :table=>:t2, :key=>[:c2]}]}
     s = @d.dump_table_schema(:t6)
-    s.should =~ /create_table\(:t6\) do\n  primary_key :c1, /
-    s.should =~ /:table=>:t2/
-    s.should =~ /:key=>\[:c2\]/
+    s.must_match(/create_table\(:t6\) do\n  primary_key :c1, /)
+    s.must_match(/:table=>:t2/)
+    s.must_match(/:key=>\[:c2\]/)
   end
 
   it "should handle foreign key options" do
@@ -118,24 +136,24 @@ describe "Sequel::Database dump methods" do
     @d.meta_def(:supports_foreign_key_parsing?){true}
     @d.meta_def(:foreign_key_list){|*s| [{:columns=>[:c1], :table=>:t2, :key=>[:c2], :on_delete=>:restrict, :on_update=>:set_null, :deferrable=>true}]}
     s = @d.dump_table_schema(:t6)
-    s.should =~ /create_table\(:t6\) do\n  foreign_key :c1, :t2, /
-    s.should =~ /:key=>\[:c2\]/
-    s.should =~ /:on_delete=>:restrict/
-    s.should =~ /:on_update=>:set_null/
-    s.should =~ /:deferrable=>true/
+    s.must_match(/create_table\(:t6\) do\n  foreign_key :c1, :t2, /)
+    s.must_match(/:key=>\[:c2\]/)
+    s.must_match(/:on_delete=>:restrict/)
+    s.must_match(/:on_update=>:set_null/)
+    s.must_match(/:deferrable=>true/)
   end
 
   it "should handle foreign key options in the primary key" do
-    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'integer', :primary_key=>true, :allow_null=>true}]]}
+    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'integer', :primary_key=>true, :allow_null=>true, :auto_increment=>true}]]}
     @d.meta_def(:supports_foreign_key_parsing?){true}
     @d.meta_def(:foreign_key_list){|*s| [{:columns=>[:c1], :table=>:t2, :key=>[:c2], :on_delete=>:restrict, :on_update=>:set_null, :deferrable=>true}]}
     s = @d.dump_table_schema(:t6)
-    s.should =~ /create_table\(:t6\) do\n  primary_key :c1, /
-    s.should =~ /:table=>:t2/
-    s.should =~ /:key=>\[:c2\]/
-    s.should =~ /:on_delete=>:restrict/
-    s.should =~ /:on_update=>:set_null/
-    s.should =~ /:deferrable=>true/
+    s.must_match(/create_table\(:t6\) do\n  primary_key :c1, /)
+    s.must_match(/:table=>:t2/)
+    s.must_match(/:key=>\[:c2\]/)
+    s.must_match(/:on_delete=>:restrict/)
+    s.must_match(/:on_update=>:set_null/)
+    s.must_match(/:deferrable=>true/)
   end
 
   it "should omit foreign key options that are the same as defaults" do
@@ -143,40 +161,40 @@ describe "Sequel::Database dump methods" do
     @d.meta_def(:supports_foreign_key_parsing?){true}
     @d.meta_def(:foreign_key_list){|*s| [{:columns=>[:c1], :table=>:t2, :key=>[:c2], :on_delete=>:no_action, :on_update=>:no_action, :deferrable=>false}]}
     s = @d.dump_table_schema(:t6)
-    s.should =~ /create_table\(:t6\) do\n  foreign_key :c1, :t2, /
-    s.should =~ /:key=>\[:c2\]/
-    s.should_not =~ /:on_delete/
-    s.should_not =~ /:on_update/
-    s.should_not =~ /:deferrable/
+    s.must_match(/create_table\(:t6\) do\n  foreign_key :c1, :t2, /)
+    s.must_match(/:key=>\[:c2\]/)
+    s.wont_match(/:on_delete/)
+    s.wont_match(/:on_update/)
+    s.wont_match(/:deferrable/)
   end
 
   it "should omit foreign key options that are the same as defaults in the primary key" do
-    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'integer', :primary_key=>true, :allow_null=>true}]]}
+    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'integer', :primary_key=>true, :allow_null=>true, :auto_increment=>true}]]}
     @d.meta_def(:supports_foreign_key_parsing?){true}
     @d.meta_def(:foreign_key_list){|*s| [{:columns=>[:c1], :table=>:t2, :key=>[:c2], :on_delete=>:no_action, :on_update=>:no_action, :deferrable=>false}]}
     s = @d.dump_table_schema(:t6)
-    s.should =~ /create_table\(:t6\) do\n  primary_key :c1, /
-    s.should =~ /:table=>:t2/
-    s.should =~ /:key=>\[:c2\]/
-    s.should_not =~ /:on_delete/
-    s.should_not =~ /:on_update/
-    s.should_not =~ /:deferrable/
+    s.must_match(/create_table\(:t6\) do\n  primary_key :c1, /)
+    s.must_match(/:table=>:t2/)
+    s.must_match(/:key=>\[:c2\]/)
+    s.wont_match(/:on_delete/)
+    s.wont_match(/:on_update/)
+    s.wont_match(/:deferrable/)
   end
 
   it "should dump primary key columns with explicit type equal to the database type when :same_db option is passed" do
     @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'somedbspecifictype', :primary_key=>true, :allow_null=>false}]]}
-    @d.dump_table_schema(:t7, :same_db => true).should == "create_table(:t7) do\n  column :c1, \"somedbspecifictype\", :null=>false\n  \n  primary_key [:c1]\nend"
+    @d.dump_table_schema(:t7, :same_db => true).must_equal "create_table(:t7) do\n  column :c1, \"somedbspecifictype\", :null=>false\n  \n  primary_key [:c1]\nend"
   end
 
   it "should use a composite primary_key calls if there is a composite primary key" do
-    @d.dump_table_schema(:t2).should == "create_table(:t2) do\n  Integer :c1, :null=>false\n  BigDecimal :c2, :null=>false\n  \n  primary_key [:c1, :c2]\nend"
+    @d.dump_table_schema(:t2).must_equal "create_table(:t2) do\n  Integer :c1, :null=>false\n  BigDecimal :c2, :null=>false\n  \n  primary_key [:c1, :c2]\nend"
   end
 
   it "should use a composite foreign_key calls if there is a composite foreign key" do
     @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'integer'}], [:c2, {:db_type=>'integer'}]]}
     @d.meta_def(:supports_foreign_key_parsing?){true}
     @d.meta_def(:foreign_key_list){|*s| [{:columns=>[:c1, :c2], :table=>:t2, :key=>[:c3, :c4]}]}
-    @d.dump_table_schema(:t1).should == "create_table(:t1) do\n  Integer :c1\n  Integer :c2\n  \n  foreign_key [:c1, :c2], :t2, :key=>[:c3, :c4]\nend"
+    @d.dump_table_schema(:t1).must_equal "create_table(:t1) do\n  Integer :c1\n  Integer :c2\n  \n  foreign_key [:c1, :c2], :t2, :key=>[:c3, :c4]\nend"
   end
 
   it "should include index information if available" do
@@ -185,11 +203,11 @@ describe "Sequel::Database dump methods" do
       {:i1=>{:columns=>[:c1], :unique=>false},
        :t1_c2_c1_index=>{:columns=>[:c2, :c1], :unique=>true}}
     end
-    @d.dump_table_schema(:t1).should == "create_table(:t1, :ignore_index_errors=>true) do\n  primary_key :c1\n  String :c2, :size=>20\n  \n  index [:c1], :name=>:i1\n  index [:c2, :c1], :unique=>true\nend"
+    @d.dump_table_schema(:t1).must_equal "create_table(:t1, :ignore_index_errors=>true) do\n  primary_key :c1\n  String :c2, :size=>20\n  \n  index [:c1], :name=>:i1\n  index [:c2, :c1], :unique=>true\nend"
   end
 
   it "should support dumping the whole database as a migration" do
-    @d.dump_schema_migration.should == <<-END_MIG
+    @d.dump_schema_migration.must_equal <<-END_MIG
 Sequel.migration do
   change do
     create_table(:t1) do
@@ -210,7 +228,7 @@ END_MIG
 
   it "should sort table names when dumping a migration" do
     @d.meta_def(:tables){|o| [:t2, :t1]}
-    @d.dump_schema_migration.should == <<-END_MIG
+    @d.dump_schema_migration.must_equal <<-END_MIG
 Sequel.migration do
   change do
     create_table(:t1) do
@@ -232,13 +250,13 @@ END_MIG
   it "should sort table names topologically when dumping a migration with foreign keys" do
     @d.meta_def(:tables){|o| [:t1, :t2]}
     @d.meta_def(:schema) do |t|
-      t == :t1 ? [[:c2, {:db_type=>'integer'}]] : [[:c1, {:db_type=>'integer', :primary_key=>true}]]
+      t == :t1 ? [[:c2, {:db_type=>'integer'}]] : [[:c1, {:db_type=>'integer', :primary_key=>true, :auto_increment=>true}]]
     end
     @d.meta_def(:supports_foreign_key_parsing?){true}
     @d.meta_def(:foreign_key_list) do |t|
       t == :t1 ? [{:columns=>[:c2], :table=>:t2, :key=>[:c1]}] : []
     end
-    @d.dump_schema_migration.should == <<-END_MIG
+    @d.dump_schema_migration.must_equal <<-END_MIG
 Sequel.migration do
   change do
     create_table(:t2) do
@@ -262,7 +280,7 @@ END_MIG
     @d.meta_def(:foreign_key_list) do |t|
       t == :t1 ? [{:columns=>[:c2], :table=>:t2, :key=>[:c1]}] : [{:columns=>[:c1], :table=>:t1, :key=>[:c2]}]
     end
-    @d.dump_schema_migration.should == <<-END_MIG
+    @d.dump_schema_migration.must_equal <<-END_MIG
 Sequel.migration do
   change do
     create_table(:t1) do
@@ -284,14 +302,14 @@ END_MIG
   it "should sort topologically even if the database raises an error when trying to parse foreign keys for a non-existent table" do
     @d.meta_def(:tables){|o| [:t1, :t2]}
     @d.meta_def(:schema) do |t|
-      t == :t1 ? [[:c2, {:db_type=>'integer'}]] : [[:c1, {:db_type=>'integer', :primary_key=>true}]]
+      t == :t1 ? [[:c2, {:db_type=>'integer'}]] : [[:c1, {:db_type=>'integer', :primary_key=>true, :auto_increment=>true}]]
     end
     @d.meta_def(:supports_foreign_key_parsing?){true}
     @d.meta_def(:foreign_key_list) do |t|
       raise Sequel::DatabaseError unless [:t1, :t2].include?(t)
       t == :t1 ? [{:columns=>[:c2], :table=>:t2, :key=>[:c1]}] : []
     end
-    @d.dump_schema_migration.should == <<-END_MIG
+    @d.dump_schema_migration.must_equal <<-END_MIG
 Sequel.migration do
   change do
     create_table(:t2) do
@@ -307,8 +325,8 @@ END_MIG
   end
 
   it "should honor the :same_db option to not convert types" do
-    @d.dump_table_schema(:t1, :same_db=>true).should == "create_table(:t1) do\n  primary_key :c1\n  column :c2, \"varchar(20)\"\nend"
-    @d.dump_schema_migration(:same_db=>true).should == <<-END_MIG
+    @d.dump_table_schema(:t1, :same_db=>true).must_equal "create_table(:t1) do\n  primary_key :c1\n  column :c2, \"varchar(20)\"\nend"
+    @d.dump_schema_migration(:same_db=>true).must_equal <<-END_MIG
 Sequel.migration do
   change do
     create_table(:t1) do
@@ -333,8 +351,8 @@ END_MIG
       {:i1=>{:columns=>[:c1], :unique=>false},
        :t1_c2_c1_index=>{:columns=>[:c2, :c1], :unique=>true}}
     end
-    @d.dump_table_schema(:t1, :index_names=>false).should == "create_table(:t1, :ignore_index_errors=>true) do\n  primary_key :c1\n  String :c2, :size=>20\n  \n  index [:c1]\n  index [:c2, :c1], :unique=>true\nend"
-    @d.dump_schema_migration(:index_names=>false).should == <<-END_MIG
+    @d.dump_table_schema(:t1, :index_names=>false).must_equal "create_table(:t1, :ignore_index_errors=>true) do\n  primary_key :c1\n  String :c2, :size=>20\n  \n  index [:c1]\n  index [:c2, :c1], :unique=>true\nend"
+    @d.dump_schema_migration(:index_names=>false).must_equal <<-END_MIG
 Sequel.migration do
   change do
     create_table(:t1, :ignore_index_errors=>true) do
@@ -365,8 +383,8 @@ END_MIG
       {:i1=>{:columns=>[:c1], :unique=>false},
        :t1_c2_c1_index=>{:columns=>[:c2, :c1], :unique=>false}}
     end
-    @d.dump_table_schema(:t1, :index_names=>:namespace).should == "create_table(:t1, :ignore_index_errors=>true) do\n  primary_key :c1\n  String :c2, :size=>20\n  \n  index [:c1], :name=>:i1\n  index [:c2, :c1]\nend"
-    @d.dump_schema_migration(:index_names=>:namespace).should == <<-END_MIG
+    @d.dump_table_schema(:t1, :index_names=>:namespace).must_equal "create_table(:t1, :ignore_index_errors=>true) do\n  primary_key :c1\n  String :c2, :size=>20\n  \n  index [:c1], :name=>:i1\n  index [:c2, :c1]\nend"
+    @d.dump_schema_migration(:index_names=>:namespace).must_equal <<-END_MIG
 Sequel.migration do
   change do
     create_table(:t1, :ignore_index_errors=>true) do
@@ -398,8 +416,8 @@ END_MIG
       {:i1=>{:columns=>[:c1], :unique=>false},
        :t1_c2_c1_index=>{:columns=>[:c2, :c1], :unique=>false}}
     end
-    @d.dump_table_schema(:t1, :index_names=>:namespace).should == "create_table(:t1, :ignore_index_errors=>true) do\n  primary_key :c1\n  String :c2, :size=>20\n  \n  index [:c1], :name=>:t1_i1\n  index [:c2, :c1]\nend"
-    @d.dump_schema_migration(:index_names=>:namespace).should == <<-END_MIG
+    @d.dump_table_schema(:t1, :index_names=>:namespace).must_equal "create_table(:t1, :ignore_index_errors=>true) do\n  primary_key :c1\n  String :c2, :size=>20\n  \n  index [:c1], :name=>:t1_i1\n  index [:c2, :c1]\nend"
+    @d.dump_schema_migration(:index_names=>:namespace).must_equal <<-END_MIG
 Sequel.migration do
   change do
     create_table(:t1, :ignore_index_errors=>true) do
@@ -430,8 +448,8 @@ END_MIG
       {:i1=>{:columns=>[:c1], :unique=>false},
        :t1_c2_c1_index=>{:columns=>[:c2, :c1], :unique=>true}}
     end
-    @d.dump_table_schema(:t1, :indexes=>false).should == "create_table(:t1) do\n  primary_key :c1\n  String :c2, :size=>20\nend"
-    @d.dump_schema_migration(:indexes=>false).should == <<-END_MIG
+    @d.dump_table_schema(:t1, :indexes=>false).must_equal "create_table(:t1) do\n  primary_key :c1\n  String :c2, :size=>20\nend"
+    @d.dump_schema_migration(:indexes=>false).must_equal <<-END_MIG
 Sequel.migration do
   change do
     create_table(:t1) do
@@ -454,7 +472,7 @@ END_MIG
     @d.meta_def(:foreign_key_list) do |t|
       t == :t1 ? [{:columns=>[:c2], :table=>:t2, :key=>[:c1]}] : []
     end
-    @d.dump_schema_migration(:indexes=>false).should_not =~ /foreign_key/
+    @d.dump_schema_migration(:indexes=>false).wont_match(/foreign_key/)
   end
 
   it "should have :foreign_keys option override :indexes => false disabling of foreign keys" do
@@ -462,7 +480,7 @@ END_MIG
     @d.meta_def(:foreign_key_list) do |t|
       t == :t1 ? [{:columns=>[:c2], :table=>:t2, :key=>[:c1]}] : []
     end
-    @d.dump_schema_migration(:indexes=>false, :foreign_keys=>true).should =~ /foreign_key/
+    @d.dump_schema_migration(:indexes=>false, :foreign_keys=>true).must_match(/foreign_key/)
   end
 
   it "should support dumping just indexes as a migration" do
@@ -472,7 +490,7 @@ END_MIG
       {:i1=>{:columns=>[:c1], :unique=>false},
        :t1_c2_c1_index=>{:columns=>[:c2, :c1], :unique=>true}}
     end
-    @d.dump_indexes_migration.should == <<-END_MIG
+    @d.dump_indexes_migration.must_equal <<-END_MIG
 Sequel.migration do
   change do
     add_index :t1, [:c1], :ignore_errors=>true, :name=>:i1
@@ -489,7 +507,7 @@ END_MIG
       {:i1=>{:columns=>[:c1], :unique=>false},
        :t1_c2_c1_index=>{:columns=>[:c2, :c1], :unique=>true}}
     end
-    @d.dump_indexes_migration(:index_names=>false).should == <<-END_MIG
+    @d.dump_indexes_migration(:index_names=>false).must_equal <<-END_MIG
 Sequel.migration do
   change do
     add_index :t1, [:c1], :ignore_errors=>true
@@ -506,7 +524,7 @@ END_MIG
       {:i1=>{:columns=>[:c1], :unique=>false},
        :t1_c2_c1_index=>{:columns=>[:c2, :c1], :unique=>false}}
     end
-    @d.dump_indexes_migration(:index_names=>:namespace).should == <<-END_MIG
+    @d.dump_indexes_migration(:index_names=>:namespace).must_equal <<-END_MIG
 Sequel.migration do
   change do
     add_index :t1, [:c1], :ignore_errors=>true, :name=>:i1
@@ -527,7 +545,7 @@ END_MIG
       {:i1=>{:columns=>[:c1], :unique=>false},
        :t1_c2_c1_index=>{:columns=>[:c2, :c1], :unique=>false}}
     end
-    @d.dump_indexes_migration(:index_names=>:namespace).should == <<-END_MIG
+    @d.dump_indexes_migration(:index_names=>:namespace).must_equal <<-END_MIG
 Sequel.migration do
   change do
     add_index :t1, [:c1], :ignore_errors=>true, :name=>:t1_i1
@@ -542,7 +560,7 @@ END_MIG
 
   it "should handle missing index parsing support when dumping index migration" do
     @d.meta_def(:tables){|o| [:t1]}
-    @d.dump_indexes_migration.should == <<-END_MIG
+    @d.dump_indexes_migration.must_equal <<-END_MIG
 Sequel.migration do
   change do
     
@@ -553,7 +571,7 @@ END_MIG
 
   it "should handle missing foreign key parsing support when dumping foreign key migration" do
     @d.meta_def(:tables){|o| [:t1]}
-    @d.dump_foreign_key_migration.should == <<-END_MIG
+    @d.dump_foreign_key_migration.must_equal <<-END_MIG
 Sequel.migration do
   change do
     
@@ -578,7 +596,7 @@ END_MIG
         []
       end
     end
-    @d.dump_foreign_key_migration.should == <<-END_MIG
+    @d.dump_foreign_key_migration.must_equal <<-END_MIG
 Sequel.migration do
   change do
     alter_table(:t1) do
@@ -595,7 +613,7 @@ END_MIG
 
   it "should handle not null values and defaults" do
     @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'date', :default=>"'now()'", :allow_null=>true}], [:c2, {:db_type=>'datetime', :allow_null=>false}]]}
-    @d.dump_table_schema(:t3).should == "create_table(:t3) do\n  Date :c1\n  DateTime :c2, :null=>false\nend"
+    @d.dump_table_schema(:t3).must_equal "create_table(:t3) do\n  Date :c1\n  DateTime :c2, :null=>false\nend"
   end
   
   it "should handle converting common defaults" do
@@ -615,8 +633,8 @@ END_MIG
       s.each{|_, c| c[:ruby_default] = column_schema_to_ruby_default(c[:default], c[:type])}
       s
     end
-    @d.dump_table_schema(:t4).gsub(/[+-]\d\d\d\d"\)/, '")').gsub(/\.0+/, '.0').should == "create_table(:t4) do\n  TrueClass :c1, :default=>false\n  String :c2, :default=>\"blah\"\n  Integer :c3, :default=>-1\n  Float :c4, :default=>1.0\n  BigDecimal :c5, :default=>BigDecimal.new(\"0.1005E3\")\n  File :c6, :default=>Sequel::SQL::Blob.new(\"blah\")\n  Date :c7, :default=>Date.new(2008, 10, 29)\n  DateTime :c8, :default=>DateTime.parse(\"2008-10-29T10:20:30.0\")\n  Time :c9, :default=>Sequel::SQLTime.parse(\"10:20:30.0\"), :only_time=>true\n  String :c10\n  Date :c11, :default=>Sequel::CURRENT_DATE\n  DateTime :c12, :default=>Sequel::CURRENT_TIMESTAMP\nend"
-    @d.dump_table_schema(:t4, :same_db=>true).gsub(/[+-]\d\d\d\d"\)/, '")').gsub(/\.0+/, '.0').should == "create_table(:t4) do\n  column :c1, \"boolean\", :default=>false\n  column :c2, \"varchar\", :default=>\"blah\"\n  column :c3, \"integer\", :default=>-1\n  column :c4, \"float\", :default=>1.0\n  column :c5, \"decimal\", :default=>BigDecimal.new(\"0.1005E3\")\n  column :c6, \"blob\", :default=>Sequel::SQL::Blob.new(\"blah\")\n  column :c7, \"date\", :default=>Date.new(2008, 10, 29)\n  column :c8, \"datetime\", :default=>DateTime.parse(\"2008-10-29T10:20:30.0\")\n  column :c9, \"time\", :default=>Sequel::SQLTime.parse(\"10:20:30.0\")\n  column :c10, \"foo\", :default=>Sequel::LiteralString.new(\"'6 weeks'\")\n  column :c11, \"date\", :default=>Sequel::CURRENT_DATE\n  column :c12, \"timestamp\", :default=>Sequel::CURRENT_TIMESTAMP\nend"
+    @d.dump_table_schema(:t4).gsub(/[+-]\d\d\d\d"\)/, '")').gsub(/\.0+/, '.0').must_equal "create_table(:t4) do\n  TrueClass :c1, :default=>false\n  String :c2, :default=>\"blah\"\n  Integer :c3, :default=>-1\n  Float :c4, :default=>1.0\n  BigDecimal :c5, :default=>BigDecimal.new(\"0.1005E3\")\n  File :c6, :default=>Sequel::SQL::Blob.new(\"blah\")\n  Date :c7, :default=>Date.new(2008, 10, 29)\n  DateTime :c8, :default=>DateTime.parse(\"2008-10-29T10:20:30.0\")\n  Time :c9, :default=>Sequel::SQLTime.parse(\"10:20:30.0\"), :only_time=>true\n  String :c10\n  Date :c11, :default=>Sequel::CURRENT_DATE\n  DateTime :c12, :default=>Sequel::CURRENT_TIMESTAMP\nend"
+    @d.dump_table_schema(:t4, :same_db=>true).gsub(/[+-]\d\d\d\d"\)/, '")').gsub(/\.0+/, '.0').must_equal "create_table(:t4) do\n  column :c1, \"boolean\", :default=>false\n  column :c2, \"varchar\", :default=>\"blah\"\n  column :c3, \"integer\", :default=>-1\n  column :c4, \"float\", :default=>1.0\n  column :c5, \"decimal\", :default=>BigDecimal.new(\"0.1005E3\")\n  column :c6, \"blob\", :default=>Sequel::SQL::Blob.new(\"blah\")\n  column :c7, \"date\", :default=>Date.new(2008, 10, 29)\n  column :c8, \"datetime\", :default=>DateTime.parse(\"2008-10-29T10:20:30.0\")\n  column :c9, \"time\", :default=>Sequel::SQLTime.parse(\"10:20:30.0\")\n  column :c10, \"foo\", :default=>Sequel::LiteralString.new(\"'6 weeks'\")\n  column :c11, \"date\", :default=>Sequel::CURRENT_DATE\n  column :c12, \"timestamp\", :default=>Sequel::CURRENT_TIMESTAMP\nend"
   end
   
   it "should not use a literal string as a fallback if using MySQL with the :same_db option" do
@@ -628,11 +646,11 @@ END_MIG
       s.each{|_, c| c[:ruby_default] = column_schema_to_ruby_default(c[:default], c[:type])}
       s
     end
-    @d.dump_table_schema(:t5, :same_db=>true).should == "create_table(:t5) do\n  column :c10, \"foo\"\nend"
+    @d.dump_table_schema(:t5, :same_db=>true).must_equal "create_table(:t5) do\n  column :c10, \"foo\"\nend"
   end
 
   it "should convert unknown database types to strings" do
-    @d.dump_table_schema(:t5).should == "create_table(:t5) do\n  String :c1\nend"
+    @d.dump_table_schema(:t5).must_equal "create_table(:t5) do\n  String :c1\nend"
   end
 
   it "should convert many database types to ruby types" do
@@ -647,12 +665,12 @@ END_MIG
       %w"nvarchar ntext smalldatetime smallmoney binary varbinary nchar" +
       ["timestamp(6) without time zone", "timestamp(6) with time zone", 'mediumint(10) unsigned', 'int(9) unsigned',
        'int(10) unsigned', "int(12) unsigned", 'bigint unsigned', 'tinyint(3) unsigned', 'identity', 'int identity'] +
-      %w"integer(10)"
+      %w"integer(10) bit"
     @d.meta_def(:schema) do |t, *o|
       i = 0
       types.map{|x| [:"c#{i+=1}", {:db_type=>x, :allow_null=>true}]}
     end
-    @d.dump_table_schema(:x).should == (<<END_MIG).chomp
+    @d.dump_table_schema(:x).must_equal((<<END_MIG).chomp)
 create_table(:x) do
   Integer :c1
   Integer :c2
@@ -726,6 +744,7 @@ create_table(:x) do
   Integer :c70
   Integer :c71
   Integer :c72
+  TrueClass :c73
   
   check Sequel::SQL::BooleanExpression.new(:>=, Sequel::SQL::Identifier.new(:c64), 0)
   check Sequel::SQL::BooleanExpression.new(:>=, Sequel::SQL::Identifier.new(:c65), 0)
@@ -743,7 +762,7 @@ END_MIG
       i = 0
       types.map{|x| [:"c#{i+=1}", {:db_type=>x, :allow_null=>true}]}
     end
-    @d.dump_table_schema(:x).should == (<<END_MIG).chomp
+    @d.dump_table_schema(:x).must_equal((<<END_MIG).chomp)
 create_table(:x) do
   Float :c1
   Float :c2
@@ -756,33 +775,33 @@ END_MIG
   it "should force specify :null option for MySQL timestamp columns when using :same_db" do
     @d.meta_def(:database_type){:mysql}
     @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'timestamp', :primary_key=>true, :allow_null=>true}]]}
-    @d.dump_table_schema(:t3, :same_db=>true).should == "create_table(:t3) do\n  column :c1, \"timestamp\", :null=>true\n  \n  primary_key [:c1]\nend"
+    @d.dump_table_schema(:t3, :same_db=>true).must_equal "create_table(:t3) do\n  column :c1, \"timestamp\", :null=>true\n  \n  primary_key [:c1]\nend"
 
     @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'timestamp', :primary_key=>true, :allow_null=>false}]]}
-    @d.dump_table_schema(:t3, :same_db=>true).should == "create_table(:t3) do\n  column :c1, \"timestamp\", :null=>false\n  \n  primary_key [:c1]\nend"
+    @d.dump_table_schema(:t3, :same_db=>true).must_equal "create_table(:t3) do\n  column :c1, \"timestamp\", :null=>false\n  \n  primary_key [:c1]\nend"
   end
 
   it "should use separate primary_key call with non autoincrementable types" do
-    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'varchar(8)', :primary_key=>true}]]}
-    @d.dump_table_schema(:t3).should == "create_table(:t3) do\n  String :c1, :size=>8\n  \n  primary_key [:c1]\nend"
-    @d.dump_table_schema(:t3, :same_db=>true).should == "create_table(:t3) do\n  column :c1, \"varchar(8)\"\n  \n  primary_key [:c1]\nend"
+    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'varchar(8)', :primary_key=>true, :auto_increment=>false}]]}
+    @d.dump_table_schema(:t3).must_equal "create_table(:t3) do\n  String :c1, :size=>8\n  \n  primary_key [:c1]\nend"
+    @d.dump_table_schema(:t3, :same_db=>true).must_equal "create_table(:t3) do\n  column :c1, \"varchar(8)\"\n  \n  primary_key [:c1]\nend"
   end
 
   it "should use explicit type for non integer foreign_key types" do
-    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'date', :primary_key=>true}]]}
+    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'date', :primary_key=>true, :auto_increment=>false}]]}
     @d.meta_def(:supports_foreign_key_parsing?){true}
     @d.meta_def(:foreign_key_list){|t, *a| [{:columns=>[:c1], :table=>:t3, :key=>[:c1]}] if t == :t4}
     ["create_table(:t4) do\n  foreign_key :c1, :t3, :type=>Date, :key=>[:c1]\n  \n  primary_key [:c1]\nend",
-     "create_table(:t4) do\n  foreign_key :c1, :t3, :key=>[:c1], :type=>Date\n  \n  primary_key [:c1]\nend"].should include(@d.dump_table_schema(:t4))
+     "create_table(:t4) do\n  foreign_key :c1, :t3, :key=>[:c1], :type=>Date\n  \n  primary_key [:c1]\nend"].must_include(@d.dump_table_schema(:t4))
     ["create_table(:t4) do\n  foreign_key :c1, :t3, :type=>\"date\", :key=>[:c1]\n  \n  primary_key [:c1]\nend",
-     "create_table(:t4) do\n  foreign_key :c1, :t3, :key=>[:c1], :type=>\"date\"\n  \n  primary_key [:c1]\nend"].should include(@d.dump_table_schema(:t4, :same_db=>true))
+     "create_table(:t4) do\n  foreign_key :c1, :t3, :key=>[:c1], :type=>\"date\"\n  \n  primary_key [:c1]\nend"].must_include(@d.dump_table_schema(:t4, :same_db=>true))
   end
 
   it "should correctly handing autoincrementing primary keys that are also foreign keys" do
-    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'integer', :primary_key=>true}]]}
+    @d.meta_def(:schema){|*s| [[:c1, {:db_type=>'integer', :primary_key=>true, :auto_increment=>true}]]}
     @d.meta_def(:supports_foreign_key_parsing?){true}
     @d.meta_def(:foreign_key_list){|t, *a| [{:columns=>[:c1], :table=>:t3, :key=>[:c1]}] if t == :t4}
     ["create_table(:t4) do\n  primary_key :c1, :table=>:t3, :key=>[:c1]\nend",
-     "create_table(:t4) do\n  primary_key :c1, :key=>[:c1], :table=>:t3\nend"].should include(@d.dump_table_schema(:t4))
+     "create_table(:t4) do\n  primary_key :c1, :key=>[:c1], :table=>:t3\nend"].must_include(@d.dump_table_schema(:t4))
   end
 end
