@@ -15,15 +15,33 @@ describe "Serialization plugin" do
   it "should allow setting additional serializable attributes via plugin :serialization call" do
     @c.plugin :serialization, :yaml, :abc
     @c.create(:abc => 1, :def=> 2)
-    DB.sqls.last.should =~ /INSERT INTO items \((abc, def|def, abc)\) VALUES \(('--- 1\n(\.\.\.\n)?', 2|2, '--- 1\n(\.\.\.\n)?')\)/
+    DB.sqls.last.must_match(/INSERT INTO items \((abc, def|def, abc)\) VALUES \(('--- 1\n(\.\.\.\n)?', 2|2, '--- 1\n(\.\.\.\n)?')\)/)
 
     @c.plugin :serialization, :marshal, :def
     @c.create(:abc => 1, :def=> 1)
-    DB.sqls.last.should =~ /INSERT INTO items \((abc, def|def, abc)\) VALUES \(('--- 1\n(\.\.\.\n)?', 'BAhpBg==\n'|'BAhpBg==\n', '--- 1\n(\.\.\.\n)?')\)/
+    DB.sqls.last.must_match(/INSERT INTO items \((abc, def|def, abc)\) VALUES \(('--- 1\n(\.\.\.\n)?', 'BAhpBg==\n'|'BAhpBg==\n', '--- 1\n(\.\.\.\n)?')\)/)
     
     @c.plugin :serialization, :json, :ghi
     @c.create(:ghi => [123])
-    DB.sqls.last.should =~ /INSERT INTO items \((ghi)\) VALUES \('\[123\]'\)/
+    DB.sqls.last.must_match(/INSERT INTO items \((ghi)\) VALUES \('\[123\]'\)/)
+  end
+
+  it "should handle validations of underlying column" do
+    @c.plugin :serialization, :yaml, :abc
+    o = @c.new
+    def o.validate
+      errors.add(:abc, "not present") unless self[:abc]
+    end
+    o.valid?.must_equal false
+    o.abc = {}
+    o.valid?.must_equal true
+  end
+
+  it "should set column values even when not validating" do
+    @c.set_primary_key :id
+    @c.plugin :serialization, :yaml, :abc
+    @c.load({:id=>1}).set(:abc=>{}).save(:validate=>false)
+    DB.sqls.last.gsub("\n", '').must_equal "UPDATE items SET abc = '--- {}' WHERE (id = 1)"
   end
 
   it "should allow serializing attributes to yaml" do
@@ -31,12 +49,12 @@ describe "Serialization plugin" do
     @c.create(:abc => 1)
     @c.create(:abc => "hello")
 
-    DB.sqls.map{|s| s.sub("...\n", '')}.should == ["INSERT INTO items (abc) VALUES ('--- 1\n')", "INSERT INTO items (abc) VALUES ('--- hello\n')"]
+    DB.sqls.map{|s| s.sub("...\n", '')}.must_equal ["INSERT INTO items (abc) VALUES ('--- 1\n')", "INSERT INTO items (abc) VALUES ('--- hello\n')"]
   end
 
   it "serialized_columns should be the columns serialized" do
     @c.plugin :serialization, :yaml, :abc
-    @c.serialized_columns.should == [:abc]
+    @c.serialized_columns.must_equal [:abc]
   end
 
   it "should allow serializing attributes to marshal" do
@@ -45,7 +63,7 @@ describe "Serialization plugin" do
     @c.create(:abc => "hello")
     x = [Marshal.dump("hello")].pack('m')
 
-    DB.sqls.should == [ \
+    DB.sqls.must_equal [ \
       "INSERT INTO items (abc) VALUES ('BAhpBg==\n')", \
       "INSERT INTO items (abc) VALUES ('#{x}')", \
     ]
@@ -57,7 +75,7 @@ describe "Serialization plugin" do
     @c.create(:ghi => ["hello"])
     
     x = ["hello"].to_json
-    DB.sqls.should == [ \
+    DB.sqls.must_equal [ \
       "INSERT INTO items (ghi) VALUES ('[1]')", \
       "INSERT INTO items (ghi) VALUES ('#{x}')", \
     ]
@@ -66,11 +84,11 @@ describe "Serialization plugin" do
   it "should allow serializing attributes using arbitrary callable" do
     @c.plugin :serialization, [proc{|s| s.reverse}, proc{}], :abc
     @c.create(:abc => "hello")
-    DB.sqls.should == ["INSERT INTO items (abc) VALUES ('olleh')"]
+    DB.sqls.must_equal ["INSERT INTO items (abc) VALUES ('olleh')"]
   end
   
   it "should raise an error if specificing serializer as an unregistered symbol" do
-    proc{@c.plugin :serialization, :foo, :abc}.should raise_error(Sequel::Error)
+    proc{@c.plugin :serialization, :foo, :abc}.must_raise(Sequel::Error)
   end
   
   it "should translate values to and from yaml serialization format using accessor methods" do
@@ -79,15 +97,15 @@ describe "Serialization plugin" do
     @c.dataset._fetch = {:id => 1, :abc => "--- 1\n", :def => "--- hello\n"}
 
     o = @c.first
-    o.id.should == 1
-    o.abc.should == 1
-    o.abc.should == 1
-    o.def.should == "hello"
-    o.def.should == "hello"
+    o.id.must_equal 1
+    o.abc.must_equal 1
+    o.abc.must_equal 1
+    o.def.must_equal "hello"
+    o.def.must_equal "hello"
 
     o.update(:abc => 23)
     @c.create(:abc => [1, 2, 3])
-    DB.sqls.should == ["SELECT * FROM items LIMIT 1",
+    DB.sqls.must_equal ["SELECT * FROM items LIMIT 1",
       "UPDATE items SET abc = '#{23.to_yaml}' WHERE (id = 1)",
       "INSERT INTO items (abc) VALUES ('#{[1, 2, 3].to_yaml}')",
       "SELECT * FROM items WHERE (id = 10) LIMIT 1"]
@@ -99,15 +117,15 @@ describe "Serialization plugin" do
     @c.dataset._fetch = [:id => 1, :abc =>[Marshal.dump(1)].pack('m'), :def =>[Marshal.dump('hello')].pack('m')]
 
     o = @c.first
-    o.id.should == 1
-    o.abc.should == 1
-    o.abc.should == 1
-    o.def.should == "hello"
-    o.def.should == "hello"
+    o.id.must_equal 1
+    o.abc.must_equal 1
+    o.abc.must_equal 1
+    o.def.must_equal "hello"
+    o.def.must_equal "hello"
 
     o.update(:abc => 23)
     @c.create(:abc => [1, 2, 3])
-    DB.sqls.should == ["SELECT * FROM items LIMIT 1",
+    DB.sqls.must_equal ["SELECT * FROM items LIMIT 1",
       "UPDATE items SET abc = '#{[Marshal.dump(23)].pack('m')}' WHERE (id = 1)",
       "INSERT INTO items (abc) VALUES ('#{[Marshal.dump([1, 2, 3])].pack('m')}')",
       "SELECT * FROM items WHERE (id = 10) LIMIT 1"]
@@ -119,8 +137,8 @@ describe "Serialization plugin" do
     @c.dataset._fetch = [:id => 1, :abc =>Marshal.dump(1), :def =>Marshal.dump('hello')]
 
     o = @c.first
-    o.abc.should == 1
-    o.def.should == "hello"
+    o.abc.must_equal 1
+    o.def.must_equal "hello"
   end
 
   it "should raise exception for bad marshal data" do
@@ -129,8 +147,8 @@ describe "Serialization plugin" do
     @c.dataset._fetch = [:id => 1, :abc =>'foo', :def =>'bar']
 
     o = @c.first
-    proc{o.abc}.should raise_error
-    proc{o.def}.should raise_error
+    proc{o.abc}.must_raise TypeError, ArgumentError
+    proc{o.def}.must_raise TypeError, ArgumentError
   end
   
   it "should translate values to and from json serialization format using accessor methods" do
@@ -139,16 +157,16 @@ describe "Serialization plugin" do
     @c.dataset._fetch = {:id => 1, :abc => [1].to_json, :def => ["hello"].to_json}
     
     o = @c.first
-    o.id.should == 1
-    o.abc.should == [1]
-    o.abc.should == [1]
-    o.def.should == ["hello"]
-    o.def.should == ["hello"]
+    o.id.must_equal 1
+    o.abc.must_equal [1]
+    o.abc.must_equal [1]
+    o.def.must_equal ["hello"]
+    o.def.must_equal ["hello"]
     
     o.update(:abc => [23])
     @c.create(:abc => [1,2,3])
     
-    DB.sqls.should == ["SELECT * FROM items LIMIT 1",
+    DB.sqls.must_equal ["SELECT * FROM items LIMIT 1",
       "UPDATE items SET abc = '#{[23].to_json}' WHERE (id = 1)",
       "INSERT INTO items (abc) VALUES ('#{[1,2,3].to_json}')",
       "SELECT * FROM items WHERE (id = 10) LIMIT 1"]
@@ -160,16 +178,16 @@ describe "Serialization plugin" do
     @c.dataset._fetch = {:id => 1, :abc => 'cba', :def => 'olleh'}
     
     o = @c.first
-    o.id.should == 1
-    o.abc.should == 'abc'
-    o.abc.should == 'abc'
-    o.def.should == "hello"
-    o.def.should == "hello"
+    o.id.must_equal 1
+    o.abc.must_equal 'abc'
+    o.abc.must_equal 'abc'
+    o.def.must_equal "hello"
+    o.def.must_equal "hello"
     
     o.update(:abc => 'foo')
     @c.create(:abc => 'bar')
     
-    DB.sqls.should == ["SELECT * FROM items LIMIT 1",
+    DB.sqls.must_equal ["SELECT * FROM items LIMIT 1",
       "UPDATE items SET abc = 'oof' WHERE (id = 1)",
       "INSERT INTO items (abc) VALUES ('rab')",
       "SELECT * FROM items WHERE (id = 10) LIMIT 1"]
@@ -177,21 +195,22 @@ describe "Serialization plugin" do
 
   it "should handle registration of custom serializer/deserializer pairs" do
     @c.set_primary_key :id
+    require 'sequel/plugins/serialization'
     Sequel::Plugins::Serialization.register_format(:reverse, proc{|s| s.reverse}, proc{|s| s.reverse})
     @c.plugin :serialization, :reverse, :abc, :def
     @c.dataset._fetch = {:id => 1, :abc => 'cba', :def => 'olleh'}
     
     o = @c.first
-    o.id.should == 1
-    o.abc.should == 'abc'
-    o.abc.should == 'abc'
-    o.def.should == "hello"
-    o.def.should == "hello"
+    o.id.must_equal 1
+    o.abc.must_equal 'abc'
+    o.abc.must_equal 'abc'
+    o.def.must_equal "hello"
+    o.def.must_equal "hello"
     
     o.update(:abc => 'foo')
     @c.create(:abc => 'bar')
     
-    DB.sqls.should == ["SELECT * FROM items LIMIT 1",
+    DB.sqls.must_equal ["SELECT * FROM items LIMIT 1",
       "UPDATE items SET abc = 'oof' WHERE (id = 1)",
       "INSERT INTO items (abc) VALUES ('rab')",
       "SELECT * FROM items WHERE (id = 10) LIMIT 1"]
@@ -203,15 +222,15 @@ describe "Serialization plugin" do
     @c.dataset._fetch = {:id => 1, :abc => "--- 1\n", :def => "--- hello\n"}
 
     o = Class.new(@c).first
-    o.id.should == 1
-    o.abc.should == 1
-    o.abc.should == 1
-    o.def.should == "hello"
-    o.def.should == "hello"
+    o.id.must_equal 1
+    o.abc.must_equal 1
+    o.abc.must_equal 1
+    o.def.must_equal "hello"
+    o.def.must_equal "hello"
 
     o.update(:abc => 23)
     Class.new(@c).create(:abc => [1, 2, 3])
-    DB.sqls.should == ["SELECT * FROM items LIMIT 1",
+    DB.sqls.must_equal ["SELECT * FROM items LIMIT 1",
       "UPDATE items SET abc = '#{23.to_yaml}' WHERE (id = 1)",
       "INSERT INTO items (abc) VALUES ('#{[1, 2, 3].to_yaml}')",
       "SELECT * FROM items WHERE (id = 10) LIMIT 1"]
@@ -222,19 +241,19 @@ describe "Serialization plugin" do
     @c.plugin :serialization, :yaml, :abc, :def
     o = @c.load(:id => 1, :abc => "--- 1\n", :def => "--- hello\n")
     o.abc = 23
-    o.deserialized_values.length.should == 1
-    o.abc.should == 23
+    o.deserialized_values.length.must_equal 1
+    o.abc.must_equal 23
     o.refresh
-    o.deserialized_values.length.should == 0
+    o.deserialized_values.length.must_equal 0
   end
   
   it "should not clear the deserialized columns when refreshing after saving a new object" do
     @c.set_primary_key :id
     @c.plugin :serialization, :yaml, :abc, :def
     o = @c.new(:abc => "--- 1\n", :def => "--- hello\n")
-    o.deserialized_values.length.should == 2
+    o.deserialized_values.length.must_equal 2
     o.save
-    o.deserialized_values.length.should == 2
+    o.deserialized_values.length.must_equal 2
   end
   
   it "should not clear the deserialized columns when refreshing after saving a new object with insert_select" do
@@ -243,17 +262,17 @@ describe "Serialization plugin" do
     def (@c.instance_dataset).supports_insert_select?() true end
     def (@c.instance_dataset).insert_select(*) {:id=>1} end
     o = @c.new(:abc => "--- 1\n", :def => "--- hello\n")
-    o.deserialized_values.length.should == 2
+    o.deserialized_values.length.must_equal 2
     o.save
-    o.deserialized_values.length.should == 2
+    o.deserialized_values.length.must_equal 2
   end
   
   it "should raise an error if calling internal serialization methods with bad columns" do
     @c.set_primary_key :id
     @c.plugin :serialization
     o = @c.load(:id => 1, :abc => "--- 1\n", :def => "--- hello\n")
-    lambda{o.send(:serialize_value, :abc, 1)}.should raise_error(Sequel::Error)
-    lambda{o.send(:deserialize_value, :abc, "--- hello\n")}.should raise_error(Sequel::Error)
+    lambda{o.send(:serialize_value, :abc, 1)}.must_raise(Sequel::Error)
+    lambda{o.send(:deserialize_value, :abc, "--- hello\n")}.must_raise(Sequel::Error)
   end
 
   it "should add the accessors to a module included in the class, so they can be easily overridden" do
@@ -264,7 +283,7 @@ describe "Serialization plugin" do
     end
     @c.plugin :serialization, :yaml, :abc
     o = @c.load(:abc => "--- 1\n")
-    o.abc.should == "1-blah"
+    o.abc.must_equal "1-blah"
   end
 
   it "should call super to get the deserialized value from a previous accessor" do
@@ -276,7 +295,7 @@ describe "Serialization plugin" do
     @c.send(:include, m)
     @c.plugin :serialization, :yaml, :abc
     o = @c.load(:abc => 3)
-    o.abc.should == 9
+    o.abc.must_equal 9
   end
 
   it "should work correctly with frozen instances" do
@@ -286,11 +305,58 @@ describe "Serialization plugin" do
 
     o = @c.first
     o.freeze
-    o.abc.should == 1
-    o.abc.should == 1
-    o.def.should == "hello"
-    o.def.should == "hello"
-    proc{o.abc = 2}.should raise_error
-    proc{o.def = 'h'}.should raise_error
+    o.abc.must_equal 1
+    o.abc.must_equal 1
+    o.def.must_equal "hello"
+    o.def.must_equal "hello"
+    proc{o.abc = 2}.must_raise
+    proc{o.def = 'h'}.must_raise
   end
+
+  it "should have dup duplicate internal structures" do
+    @c.plugin :serialization, :yaml, :abc, :def
+    o = @c.new
+    o.dup.deserialized_values.must_equal o.deserialized_values
+    o.dup.deserialized_values.wont_be_same_as(o.deserialized_values)
+  end
+
+  it "should have changed_columns include serialized columns if those columns have changed" do
+    @c.plugin :serialization, :yaml, :abc, :def
+    @c.dataset._fetch = {:id => 1, :abc => "--- 1\n", :def => "--- hello\n"}
+    o = @c.first
+    o.changed_columns.must_equal []
+    o.abc = 1
+    o.changed_columns.must_equal []
+    o.abc = 1
+    o.changed_columns.must_equal []
+    o.abc = 2
+    o.changed_columns.must_equal [:abc]
+    o.def = 'hello'
+    o.changed_columns.must_equal [:abc]
+    o.def = 'hello'
+    o.changed_columns.must_equal [:abc]
+    o.def = 'hello2'
+    o.changed_columns.must_equal [:abc, :def]
+  end
+
+  it "should update column_changes if the dirty plugin is used" do
+    @c.plugin :serialization, :yaml, :abc, :def
+    @c.plugin :dirty
+    @c.dataset._fetch = {:id => 1, :abc => "--- 1\n", :def => "--- hello\n"}
+    o = @c.first
+    o.column_changes.must_equal({})
+    o.abc = 1
+    o.column_changes.must_equal({})
+    o.abc = 1
+    o.column_changes.must_equal({})
+    o.abc = 2
+    o.column_changes.must_equal(:abc=>[1, 2])
+    o.def = 'hello'
+    o.column_changes.must_equal(:abc=>[1, 2])
+    o.def = 'hello'
+    o.column_changes.must_equal(:abc=>[1, 2])
+    o.def = 'hello2'
+    o.column_changes.must_equal(:abc=>[1, 2], :def=>["hello", "hello2"])
+  end
+
 end
