@@ -1,26 +1,26 @@
 require File.join(File.dirname(File.expand_path(__FILE__)), "spec_helper")
 
-shared_examples_for "Database#with_server" do  
-  specify "should set the default server to use in the block" do
+with_server_specs = shared_description do
+  it "should set the default server to use in the block" do
     @db.with_server(:a){@db[:t].all}
-    @db.sqls.should == ["SELECT * FROM t -- a"]
+    @db.sqls.must_equal ["SELECT * FROM t -- a"]
     @db.with_server(:b){@db[:t].all}
-    @db.sqls.should == ["SELECT * FROM t -- b"]
+    @db.sqls.must_equal ["SELECT * FROM t -- b"]
   end
 
-  specify "should have no affect after the block" do
+  it "should have no affect after the block" do
     @db.with_server(:a){@db[:t].all}
-    @db.sqls.should == ["SELECT * FROM t -- a"]
+    @db.sqls.must_equal ["SELECT * FROM t -- a"]
     @db[:t].all
-    @db.sqls.should == ["SELECT * FROM t"]
+    @db.sqls.must_equal ["SELECT * FROM t"]
   end
 
-  specify "should not override specific server inside the block" do
+  it "should not override specific server inside the block" do
     @db.with_server(:a){@db[:t].server(:b).all}
-    @db.sqls.should == ["SELECT * FROM t -- b"]
+    @db.sqls.must_equal ["SELECT * FROM t -- b"]
   end
 
-  specify "should work correctly when blocks are nested" do
+  it "should work correctly when blocks are nested" do
     @db[:t].all
     @db.with_server(:a) do
       @db[:t].all
@@ -28,16 +28,16 @@ shared_examples_for "Database#with_server" do
       @db[:t].all
     end
     @db[:t].all
-    @db.sqls.should == ["SELECT * FROM t", "SELECT * FROM t -- a", "SELECT * FROM t -- b", "SELECT * FROM t -- a", "SELECT * FROM t"]
+    @db.sqls.must_equal ["SELECT * FROM t", "SELECT * FROM t -- a", "SELECT * FROM t -- b", "SELECT * FROM t -- a", "SELECT * FROM t"]
   end
 
-  specify "should work correctly for inserts/updates/deletes" do
+  it "should work correctly for inserts/updates/deletes" do
     @db.with_server(:a) do
       @db[:t].insert
       @db[:t].update(:a=>1)
       @db[:t].delete
     end
-    @db.sqls.should == ["INSERT INTO t DEFAULT VALUES -- a", "UPDATE t SET a = 1 -- a", "DELETE FROM t -- a"]
+    @db.sqls.must_equal ["INSERT INTO t DEFAULT VALUES -- a", "UPDATE t SET a = 1 -- a", "DELETE FROM t -- a"]
   end
 end
 
@@ -47,7 +47,7 @@ describe "Database#with_server single threaded" do
     @db.extension :server_block
   end
 
-  it_should_behave_like "Database#with_server"
+  include with_server_specs
 end
 
 describe "Database#with_server multi threaded" do
@@ -56,9 +56,9 @@ describe "Database#with_server multi threaded" do
     @db.extension :server_block
   end
 
-  it_should_behave_like "Database#with_server"
+  include with_server_specs
 
-  specify "should respect multithreaded access" do
+  it "should respect multithreaded access" do
     q, q1 = Queue.new, Queue.new
     
     t = nil
@@ -83,7 +83,7 @@ describe "Database#with_server multi threaded" do
     @db[:t].all
     q1.push nil
     t.join
-    @db.sqls.should == ["SELECT * FROM t", "SELECT * FROM t -- a", "SELECT * FROM t", "SELECT * FROM t -- c", "SELECT * FROM t -- d",
+    @db.sqls.must_equal ["SELECT * FROM t", "SELECT * FROM t -- a", "SELECT * FROM t", "SELECT * FROM t -- c", "SELECT * FROM t -- d",
       "SELECT * FROM t -- b", "SELECT * FROM t -- a", "SELECT * FROM t", "SELECT * FROM t -- c", "SELECT * FROM t"]
   end
 end
